<?php 
/*==========================
betube-ads: Meta Box Data
===========================*/
if ( ! function_exists( 'add_custom_meta_box' ) ) {
	add_action("add_meta_boxes", "add_custom_meta_box");
	function add_custom_meta_box(){
		add_meta_box( 
			'betube-ads',
			esc_html__( 'BeTube Custom Ads', 'betube-ads' ),
			'betube_select_ads_type',
			'video-ads',
			'normal',
			'high'
		);   
	}
}
if ( ! function_exists( 'betube_select_ads_type' ) ) {
	function betube_select_ads_type($post){
		global $typevalue;
		wp_nonce_field( 'betube_ads_type_meta', 'betube_ads_type_meta_nonce' );
		$typevalue = get_post_meta($post->ID, "meta-box-dropdown", true);
		?>
		<div class="beAds-meta form-wrap">
			<!--Ads Type-->
			<label for="videoAdv">
				<?php esc_html_e( 'Select Ads Type', 'betube-ads' );?>
			</label>
			<select id= "videoAdv" name="meta-box-dropdown" required>
				<option value="image" <?php selected( $typevalue, 'image', true); ?>>
						<?php esc_html_e('Image banner', 'betube-ads'); ?>
				</option>
				<option value="video" <?php selected( $typevalue, 'video', true); ?>>
						<?php esc_html_e('Video URL', 'betube-ads'); ?>
				</option>
				<option value="html" <?php selected( $typevalue, 'html', true); ?>>
						<?php esc_html_e('HTML code', 'betube-ads'); ?>
				</option>
			</select>
			<br>
			<!--Ads Type-->
			<!--Image Ads-->
			<div id="image" style="display:<?php echo ($typevalue == 'image') ? 'block' : 'none'; ?>">
				<p><?php esc_html_e( 'If You want to use Image Ads then Set Thumbnail form right side, Otherwise leave it.', 'betube-ads' );?></p>
				<label for="be-img-url"><?php esc_html_e( 'Click able URL', 'betube-ads' );?></label>
				<input name="be-img-url" type="text" style="width:50%;" placeholder="<?php esc_html_e( 'www.google.com', 'betube-ads' );?>" value="<?php echo get_post_meta($post->ID, "be-img-url", true); ?>">			
			</div>
			<!--Image Ads-->
			<!--Video URL-->
			<div id="video" style="display:<?php echo ($typevalue == 'video') ? 'block' : 'none'; ?>">
				<p><?php esc_html_e( 'If you are using Video Ads then don&rsquo;t upload image as a thumbnail', 'betube-ads' );?></p>
				<label for="meta-box-text"><?php esc_html_e( 'Video URL', 'betube-ads' );?></label>
				<input name="meta-box-text" type="text" style="width:50%;" value="<?php echo get_post_meta($post->ID, "meta-box-text", true); ?>">
				<p class="videoURLtxt"><?php esc_html_e( 'Video URL from YouTube or Vimeo. Ex: ', 'betube-ads' );?>https://www.youtube.com/watch?v=0bYUOxl8BX0</p>
				<br>
			</div>
			<!--Video URL-->
			<!--HTML Ads-->
			<style>
			label#meta-html-code{
			 vertical-align: top;
			}
			</style>
			<div id="html" style="display:<?php echo ($typevalue == 'html') ? 'block' : 'none'; ?>">
				<p><?php esc_html_e( 'If you are using HTML for ads then don&rsquo;t upload image as a thumbnail.', 'betube-ads' );?></p>
				<label id="meta-html-code" for="meta-html-code"><?php esc_html_e( 'HTML Ad', 'betube-ads' );?></label>
				<textarea id="meta-html-code" name="meta-html-code" cols="60"><?php echo get_post_meta($post->ID, "meta-html-code", true); ?></textarea>
			</div>
			<br />
			<!--HTML Ads-->
			<!--Data Picker-->
			<p><?php esc_html_e( 'How Many days this ad will be active? Please put number of days like (1 or 30 or 60)', 'betube-ads' );?></p>
			<label for="bedatepicker"><?php esc_html_e( 'Expiry Date', 'betube-ads' );?></label>
			<input id="bedatepicker" name="bedatepicker" type="text" value="<?php echo get_post_meta($post->ID, "bedatepicker", true); ?>">
			<!--Data Picker-->
		</div>
		<?php
		
	}
}
/*==========================
betube-ads: Meta Box Save Function
===========================*/
if ( ! function_exists( 'save_custom_meta_box' ) ) {
	add_action( 'save_post', 'save_custom_meta_box' );
	function save_custom_meta_box($post_id){
		global $post;
		if( !isset( $_POST['betube_ads_type_meta_nonce'] ) || !wp_verify_nonce( $_POST['betube_ads_type_meta_nonce'], 'betube_ads_type_meta' ) ) {
			return;
		}
		if(!current_user_can("edit_post", $post_id)){
			return;
		}
		if(defined("DOING_AUTOSAVE") && DOING_AUTOSAVE){
			return;
		}    
		if($post->post_type != 'video-ads'){
			return;
		}
		if(isset($_POST["meta-box-text"])){
			update_post_meta($post_id, "meta-box-text", $_POST["meta-box-text"]);
		} 
		if(isset($_POST["be-img-url"])){
			update_post_meta($post_id, "be-img-url", $_POST["be-img-url"]);
		}
		if(isset($_POST["meta-box-dropdown"])){
			update_post_meta($post_id, "meta-box-dropdown", $_POST["meta-box-dropdown"]);
		}	
		if(isset($_POST["meta-html-code"])){
			update_post_meta($post_id, "meta-html-code", $_POST["meta-html-code"]);
		}
		if(isset($_POST["bedatepicker"])){
			update_post_meta($post_id, "bedatepicker", $_POST["bedatepicker"]);
		} 
	}
}
/*==========================
betube-ads: Ads Meta Data Table
===========================*/
if ( ! function_exists( 'betube_ads_custom_colums' ) ) {
	add_action( 'manage_posts_custom_column' , 'betube_ads_custom_colums', 10, 2 );
	function betube_ads_custom_colums( $column ) {
		global $post;		
		switch ( $column ) {
            case 'id':
                echo $post->ID;
            break;
			case 'bedatepicker':
				$days = get_post_meta($post->ID, 'bedatepicker', TRUE);	
				echo $days. esc_html__( ' Days', 'betube-ads' );
			break;
		}
	}
}
?>