<?php
/**
 *	Plugin Name: Betube Elementor
 *	Description: This plugin will help you to build your website using Elementor
 *	with Betube
 *	Plugin URI:  https://themeforest.net/item/betube-video-wordpress-theme/16437378
 *	Version:     1.0.0
 *	Author:      JoinWebs
 *	Author URI:  https://joinwebs.com/
 *	Text Domain: betube-elementor
*/
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
define( 'BE_VERSION', '1.0.0' );
define( 'BE_REQUIRED_WP_VERSION', '5.0' );
define( 'BE_PLUGIN', __FILE__ );
define( 'BE_PLUGIN_BASENAME', plugin_basename( BE_PLUGIN ) );
define( 'BE_PLUGIN_NAME', trim( dirname( BE_PLUGIN_BASENAME ), '/' ) );
define( 'WPBE_PLUGIN_DIR', untrailingslashit( dirname( BE_PLUGIN ) ) );
define( 'WPBE_PLUGIN_WIDGETS_DIR', WPBE_PLUGIN_DIR . '/widgets/' );
/***********************
Main Betube Elementor Extension Class
The main class that initiates and runs the plugin.
@since 1.0.0
**********************/
final class betube_elementor_extension {
	const VERSION = '1.0.0';
	/***********************
	Minimum Elementor Version
	@since 1.0.0
	@var string Minimum Elementor version required to run the plugin.
	**********************/
	const MINIMUM_ELEMENTOR_VERSION = '2.0.0';
	/***********************
	Minimum PHP Version
	@since 1.0.0
	@var string Minimum PHP version required to run the plugin.
	**********************/
	const MINIMUM_PHP_VERSION = '7.0';	
	
	/***********************
	* Instance
	@since 1.0.0
	@access private
	@static
	@var betube_elementor_extension The single instance of the class.
	**********************/
	private static $_instance = null;
	/***********************
	Instance
	Ensures only one instance of the class is loaded or can be loaded.
	@since 1.0.0
	@access public
	@static
	@return betube_elementor_extension An instance of the class.
	**********************/
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}
	/**********************
	The real constructor to initialize
	@since  1.0.0
	@access public
	**********************/
	public function __construct() {
		add_action( 'init', [ $this, 'i18n' ] );
		add_action( 'plugins_loaded', [ $this, 'init' ] );
	}
	/**********************
	Load Text domain
	Load plugin localization files.
	Fired by `init` action hook.
	@since 1.0.0
	@access public
	**********************/
	public function i18n() {
		load_plugin_textdomain( 'betube-elementor' );
	}
	/**********************
	Initialize the plugin
	Load the plugin only after Elementor (and other plugins) are loaded.
	Checks for basic plugin requirements, if one check fail don't continue,
	if all check have passed load the files required to run the plugin.
	Fired by `plugins_loaded` action hook.
	@since 1.0.0
	@access public
	**********************/
	public function init() {
		if ( ! did_action( 'elementor/loaded' ) ) {
            add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
            return;
        }
		/**********************
		// Check for required Elementor version.
		**********************/	
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
            add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
            return;
        }
		/**********************
		// Check for required PHP version.
		**********************/
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
            add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
            return;
        }
		function classiera_add_elementor_widget_categories( $elements_manager ){
			$elements_manager->add_category(
				'betube',
				[
					'title' => __( 'Betube', 'betube-elementor' ),
					'icon' => 'fa fa-plug',
				]
			);
		}
		add_action( 'elementor/elements/categories_registered', 'classiera_add_elementor_widget_categories' );
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'register_widgets' ] );
	}
	/**********************
	Admin notice
	Warning when the site doesn't have Elementor installed or activated.
	@since  1.0.0
	@access public
	**********************/
	public function admin_notice_missing_main_plugin() {
        if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );
        $message = sprintf(
            /* translators: 1: Plugin name 2: Elementor */
            esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'elementor-test-extension' ),
            '<strong>' . esc_html__( 'Betube Elementor', 'betube-elementor' ) . '</strong>',
            '<strong>' . esc_html__( 'Elementor', 'betube-elementor' ) . '</strong>'
        );
        printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
    }
	/**********************
	Admin notice
	Warning when the site doesn't have a minimum required Elementor version.
	@since  1.0.0
	@access public
	**********************/
	public function admin_notice_minimum_elementor_version() {

        if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

        $message = sprintf(
            /* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
            esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'elementor-test-extension' ),
            '<strong>' . esc_html__( 'Betube Elementor', 'betube-elementor' ) . '</strong>',
            '<strong>' . esc_html__( 'Elementor', 'betube-elementor' ) . '</strong>',
             self::MINIMUM_ELEMENTOR_VERSION
        );

        printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

    }
	/**********************
	Admin notice
	Warning when the site doesn't have a minimum required PHP version.
	@since  1.0.0
	@access public
	**********************/
	public function admin_notice_minimum_php_version() {

        if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

        $message = sprintf(
            /* translators: 1: Plugin name 2: PHP 3: Required PHP version */
            esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'elementor-test-extension' ),
            '<strong>' . esc_html__( 'Betube Elementor', 'betube-elementor' ) . '</strong>',
            '<strong>' . esc_html__( 'PHP', 'betube-elementor' ) . '</strong>',
             self::MINIMUM_PHP_VERSION
        );

        printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

    }
	/**********************
	Include Files
	Load required plugin core files.
	@since 1.0.0
	@access public
	**********************/
	public function includes() {		
		require_once WPBE_PLUGIN_WIDGETS_DIR . 'categories-widget.php';
		require_once WPBE_PLUGIN_WIDGETS_DIR . 'blogs-widget.php';
		require_once WPBE_PLUGIN_WIDGETS_DIR . 'movies-widget.php';
		require_once WPBE_PLUGIN_WIDGETS_DIR . 'videos-widget.php';
		require_once WPBE_PLUGIN_WIDGETS_DIR . 'trending-widget.php';
		require_once WPBE_PLUGIN_WIDGETS_DIR . 'video-slider-widget.php';
	}
	/**********************
	Register Widgets
	**********************/
	public function register_widgets() {
		$this->includes();
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \betube_category_styles() );		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \betube_blogs_styles() );		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \betube_movies_styles() );		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \betube_videos_styles() );		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \betube_trending_videos() );		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \betube_videos_slider_styles() );		
 	}
}
betube_elementor_extension::instance();