<?php
use Elementor\Plugin;
use Elementor\Controls_Manager;
class betube_blogs_styles extends \Elementor\Widget_Base {
	public function get_name() {
		return 'betube-blogs-styles';
	}
	public function get_title() {
		return esc_html__( 'Betube Blogs', 'betube-elementor' );
	}
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	public function get_categories() {
		return [ 'betube' ];
	}
	protected function register_controls() {
		$this->start_controls_section(
			'setting_section',
			[
				'label' => __( 'Setting', 'betube-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control( 'layout_style', [
			'label'   => esc_html__( 'Section style', 'betube-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'options' => [
				'boxed'=> esc_html__( 'Boxed', 'betube-elementor' ),
				'wide'=> esc_html__( 'Wide', 'betube-elementor' ),
			],
			'default' => 'wide',
		] );
		$this->add_control(
            's_title',
            [
                'label' => __( 'Section title', 'betube-elementor' ),
                'type' => Controls_Manager::TEXT,
                'input_type' => 'text',
                'placeholder' => __( 'Enter your title', 'betube-elementore' ),
				'default' => 'Latest News',
            ]
        );
		$this->add_control( 'orderby', [
			'label'   => esc_html__( 'Order by', 'betube-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'options' => [
				'title'=> esc_html__( 'Order by title', 'betube-elementor' ),
				'name'=> esc_html__( 'Order by name', 'betube-elementor' ),
				'date'=> esc_html__( 'Order by date', 'betube-elementor' ),
				'rand'=> esc_html__( 'Order by random', 'betube-elementor' ),
			],
			'default' => 'rand',
		] );
		$this->add_control( 'order', [
			'label'   => esc_html__( 'Order', 'betube-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'options' => [
				'ASC'=> esc_html__( 'Order by ASC', 'betube-elementor' ),
				'DESC'=> esc_html__( 'Order by DESC', 'betube-elementor' ),
			],
			'default' => 'ASC',
		] );
		$this->add_control(
            'nop',
            [
                'label' => __( 'Number of posts', 'betube-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'input_type' => 'text',
                'placeholder' => __( 'Enter a number', 'betube-elementore' ),
				'default' => '5',
            ]			
        );
		$this->add_control(
            'btntxt',
            [
                'label' => __( 'View Button', 'betube-elementor' ),
                'type' => Controls_Manager::TEXT,
                'input_type' => 'text',
                'placeholder' => __( 'Replace button text', 'betube-elementor' ),
				'default' => 'View All',
            ]
        );
		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings_for_display();
		$atts = array(			
			'layout' => $settings['layout_style'],		
			'orderby' => $settings['orderby'],		
			'order' => $settings['order'],		
			'nop' => $settings['nop'],
			'btntxt' => $settings['btntxt'],
			's_title' => $settings['s_title'],
		);
		/***********************
		convert to vars
		**********************/			
		$sectionLayout = $settings['layout_style'];
		$orderby = $settings['orderby'];
		$order = $settings['order'];
		$nop = $settings['nop'];
		$sectionBtnTxt = $settings['btntxt'];
		$sectionTitle = $settings['s_title'];
		$args = array (
			'post_type' => 'blog',
			'post_status' => 'publish',
			'posts_per_page' => $nop,
			'order' => $order,
			'orderby' => $orderby,
		);
		global $redux_demo, $post;
		$betube_img_opti = true;
		$beTubedateFormat = get_option( 'date_format' );
		if (  class_exists( 'Redux' ) ) {   
		   $redux_demo = get_option( 'redux_demo' );
		   $betube_img_opti = $redux_demo['betube_img_opti'];
		}		
		$blogSecQuery = new WP_Query($args);
		if ( $blogSecQuery->have_posts() ){
			?>
			<section class="btp_blog pb-3">
				<div class="container<?php if($sectionLayout == 'wide'){ echo "-fluid"; }?>">
					<div class="row">
						<div class="col-12">
							<div class="btp_section_head d-flex justify-content-between align-items-center mb-4">
								<h4 class="btp_section_head__title mb-0">
									<?php echo esc_html($sectionTitle); ?>
								</h4>
								<div class="btp_section_head__btns">
									<a href="<?php echo get_post_type_archive_link( 'blog' ); ?>" class="text-primary font-weight-bold mr-2 text-decoration-none">
										<?php echo esc_html($sectionBtnTxt); ?>
									</a>
									<button class="btp_carousel_btn rounded carousel__btn_prev d-none d-md-inline-flex btn-outline-primary btn btn-sm">
										<i class="fas fa-angle-<?php if(is_rtl()){ echo "right";}else{ echo "left";}?> btp_carousel_btn__icon"></i>
									</button>
									<button class="btp_carousel_btn rounded carousel__btn_next d-none d-md-inline-flex btn-outline-primary btn btn-sm">
										<i class="fas fa-angle-<?php if(is_rtl()){ echo "left"; }else{echo "right"; }?> btp_carousel_btn__icon"></i>
									</button>
								</div><!--btp_section_head__btns-->
							</div><!--btp_section_head-->
						</div><!--col-12-->
						<div class="col-12">
							<div class="swiper-container" data-slides-per-view="3" data-space-between="30" data-loop="true" data-free-mode="true" data-click="false" data-center-xs-slide="false" data-spvxs="auto" data-spvsm="2" data-spvmd="2" data-spvlg="auto" data-spvxl="auto">
								<div class="swiper-wrapper">
								<?php
								while ( $blogSecQuery->have_posts() ) : $blogSecQuery->the_post();
								if( has_post_thumbnail()){				
									if($betube_img_opti == true){
										$postThumb = get_the_post_thumbnail_url($post->ID, 'betube-blog');
									}else{
										$postThumb = get_the_post_thumbnail_url($post->ID, 'thumbnail');
									}
								}
								?>
								<div class="swiper-slide btp_blog_slide">
									<div class="card bg-transparent border-0 btp_blog_card mb-4">
										<?php if( has_post_thumbnail()){ ?>
										<a href="<?php the_permalink(); ?>">
											<img class="img-fluid mb-3 btp_blog_card__img" src="<?php echo esc_url($postThumb)?>" alt="<?php echo get_the_title();?>">
										</a>
										<?php } ?>
										<h6 class="block_with_heading">
											<a href="<?php the_permalink(); ?>" class="text-decoration-none btp_blog_card__title">
												<?php echo get_the_title();?>
											</a>
										</h6>
										<p class="block_with_text"><?php echo get_the_excerpt(); ?></p>
										<div class="d-flex btp_blog_card__footer">
											<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>" class="small text-decoration-none mr-auto btp_blog_card__link">
												<i class="fas fa-user-circle mr-1"></i>
												<span><?php the_author(); ?></span>
											</a>
											<span class="small">
												<i class="far fa-calendar mr-1"></i>
												<span><?php echo get_the_date($beTubedateFormat, $post->ID); ?></span>
											</span>
											<a href="<?php the_permalink(); ?>" class="small text-decoration-none ml-3 btp_blog_card__link">
												<i class="far fa-comment mr-1"></i>
												<span><?php echo comments_number(); ?></span>
											</a>
										</div><!--btp_blog_card__footer-->
									</div><!--card-->
								</div><!--btp_blog_slide-->
								<?php endwhile; ?>
								</div><!--swiper-wrapper-->
							</div><!--swiper-container-->
						</div><!--col-12-->
					</div><!--row-->
				</div><!--container-->
			</section>
		<?php
		}wp_reset_query();
	}
}