<?php
use Elementor\Plugin;
use Elementor\Controls_Manager;
class betube_category_styles extends \Elementor\Widget_Base {
	public function get_name() {
		return 'betube-categories-slider';
	}
	public function get_title() {
		return esc_html__( 'Betube Categories', 'betube-elementor' );
	}
	public function get_icon() {
		return 'eicon-post-list';
	}
	public function get_categories() {
		return [ 'betube' ];
	}
	protected function register_controls() {
		$this->start_controls_section(
			'setting_section',
			[
				'label' => __( 'Setting', 'betube-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
            's_title',
            [
                'label' => __( 'Section title', 'betube-elementor' ),
                'type' => Controls_Manager::TEXT,
                'input_type' => 'text',
                'placeholder' => __( 'Enter your title', 'betube-elementore' ),
				'default' => 'Browse categories',
            ]
        );
		$this->add_control( 'layout_style', [
			'label'   => esc_html__( 'Categories style', 'betube-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'options' => [
				'boxed'=> esc_html__( 'Boxed', 'betube-elementor' ),
				'wide'=> esc_html__( 'Wide', 'betube-elementor' ),
			],
			'default' => 'wide',
		] );
		/*====Show WordPress Post categories ====*/
		$options = array();
		$args = array(
			'hide_empty' => false,
			'parent' => 0,
			'orderby' => 'name',
		);
		$categories = get_categories($args);
		if($categories){
			foreach ( $categories as $key => $category ) {
				$options[$category->term_id] = $category->name;
			}
		}		
		$this->add_control( 'select_cats', [
			'label'   => esc_html__( 'Select Categories', 'betube-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'multiple' => true,
			'options' => $options,
			'default' => '1',
		] );
		/*====Show WordPress Post categories ====*/
		$this->add_control(
            'noc',
            [
                'label' => __( 'Number of categories', 'betube-elementor' ),
                'type' => Controls_Manager::TEXT,
                'input_type' => 'text',
                'placeholder' => __( 'Enter a number', 'betube-elementore' ),
            ]
        );
		$this->add_control(
            'btntxt',
            [
                'label' => __( 'View Button', 'betube-elementor' ),
                'type' => Controls_Manager::TEXT,
                'input_type' => 'text',
                'placeholder' => __( 'Replace button text', 'betube-elementor' ),
				'default' => 'View All',
            ]
        );
		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings_for_display();
		$atts = array(			
			's_title' => $settings['s_title'],					
			'layout_style' => $settings['layout_style'],					
			'select_cats' => $settings['select_cats'],					
			'noc' => $settings['noc'],					
			'btntxt' => $settings['btntxt'],					
		);
		/***********************
		convert to vars
		**********************/	
		$sectionTitle = $settings['s_title'];	
		$sectionLayout = $settings['layout_style'];
		$sectionCats = $settings['select_cats'];
		$sectionCatsNo = $settings['noc'];
		$sectionBtnTxt = $settings['btntxt'];
		?>
		<section class="btp_categories pb-3">
			<div class="container<?php if($sectionLayout == 'wide'){ echo "-fluid"; }?>">
				<div class="row">
					<div class="col-12">
						<div class="btp_section_head d-flex justify-content-between align-items-center mb-4">
							<h4 class="btp_section_head__title mb-0">
								<?php echo esc_html($sectionTitle); ?>
							</h4>
							<div class="btp_section_head__btns">
								<a href="<?php echo esc_url($betubeAllCatURL);?>" class="text-primary font-weight-bold mr-2 text-decoration-none">
									<?php echo esc_html($sectionBtnTxt); ?>
								</a>
								<button class="btp_carousel_btn rounded carousel__btn_prev d-none d-md-inline-flex btn-outline-primary btn btn-sm">
									<i class="fas fa-angle-<?php if(is_rtl()){ echo "right";}else{ echo "left";}?> btp_carousel_btn__icon"></i>
								</button>
								<button class="btp_carousel_btn rounded carousel__btn_next d-none d-md-inline-flex btn-outline-primary btn btn-sm">
									<i class="fas fa-angle-<?php if(is_rtl()){ echo "left"; }else{echo "right"; }?> btp_carousel_btn__icon"></i>
								</button>
							</div><!--btp_section_head__btns-->
						</div><!--btp_section_head-->
					</div><!--col-12-->
					<div class="col-12">
						<div class="swiper-container border-bottom" data-slides-per-view="6" data-space-between="15" data-loop="true" data-free-mode="true" data-click="false" data-center-xs-slide="false" data-spvxs="auto" data-spvsm="auto" data-spvmd="auto" data-spvlg="auto" data-spvxl="auto">
							<div class="swiper-wrapper">
								<?php
								$args = array(
									'hide_empty' => false,
									'parent' => false,
									'number' => $sectionCatsNo,
									'order' => 'ASC',
									'include' => $sectionCats,
								);
								$categorieslist = get_terms('category', $args);
								if($categorieslist){
									foreach ($categorieslist as $category) {
										$termID = $category->term_id;
										$beeCatThumb  = get_term_meta( $termID, 'your_image_url', true);
										?>
										<div class="swiper-slide btp_cat_slide mb-4">
											<div class="card btp_cat_card border-0">
												<?php if(!empty($beeCatThumb)){?>
												<img class="btp_cat_card__img" src="<?php echo esc_url($beeCatThumb); ?>" alt="<?php echo get_cat_name( $termID ); ?>">
												<?php }?>
												<a href="<?php echo get_category_link( $termID ); ?>" class="text-decoration-none card-img-overlay btp_cat_card_img_overlay d-flex flex-column justify-content-end p-0">
													<h5 class="text-center btp_cat_card__title font-weight-bold mb-0 text-white">
														<?php echo get_cat_name( $termID ); ?>
													</h5>
												</a>
											</div>
										</div>
										<?php
									}
								}
								?>
							</div><!--swiper-wrapper-->
						</div><!--swiper-container-->
					</div><!--col-12-->
				</div><!--row-->
			</div><!--container-->
		</section>
		<?php
	}
}