<?php
use Elementor\Plugin;
use Elementor\Controls_Manager;
class betube_trending_videos extends \Elementor\Widget_Base {
	public function get_name() {
		return 'betube-trending-videos';
	}
	public function get_title() {
		return esc_html__( 'Betube Trending Videos', 'betube-elementor' );
	}
	public function get_icon() {
		return 'eicon-slider-video';
	}
	public function get_categories() {
		return [ 'betube' ];
	}
	protected function register_controls() {
		$this->start_controls_section(
			'setting_section',
			[
				'label' => __( 'Setting', 'betube-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control( 'layout_style', [
			'label'   => esc_html__( 'Section style', 'betube-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'options' => [
				'boxed'=> esc_html__( 'Boxed', 'betube-elementor' ),
				'wide'=> esc_html__( 'Wide', 'betube-elementor' ),
			],
			'default' => 'wide',
		] );
		$this->add_control( 'post_type', [
			'label'   => esc_html__( 'Post Type', 'betube-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'options' => [
				'featured'=> esc_html__( 'Featured Only', 'betube-elementor' ),
				'all'=> esc_html__( 'All Videos', 'betube-elementor' ),
			],
			'default' => 'featured',
		] );
		/*====Show WordPress Post categories ====*/
		$options = array();
		$args = array(
			'hide_empty' => false,
			'parent' => 0,
			'orderby' => 'name',
		);
		$categories = get_categories($args);
		if($categories){
			foreach ( $categories as $key => $category ) {
				$options[$category->term_id] = $category->name;
			}
		}		
		$this->add_control( 'select_cats', [
			'label'   => esc_html__( 'Select Categories', 'betube-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'multiple' => true,
			'options' => $options,
			'default' => '1',
		] );
		/*====Show WordPress Post categories ====*/
		$this->add_control(
            's_title',
            [
                'label' => __( 'Section title', 'betube-elementor' ),
                'type' => Controls_Manager::TEXT,
                'input_type' => 'text',
                'placeholder' => __( 'Enter your title', 'betube-elementore' ),
				'default' => 'Trending Videos',
            ]
        );				
		$this->add_control(
            'nop',
            [
                'label' => __( 'Number of posts', 'betube-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'input_type' => 'text',
                'placeholder' => __( 'Enter a number', 'betube-elementore' ),
				'default' => '5',
            ]			
        );
		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings_for_display();
		$atts = array(			
			'layout' => $settings['layout_style'],		
			'post_type' => $settings['post_type'],
			'select_cats' => $settings['select_cats'],		
			'nop' => $settings['nop'],
			's_title' => $settings['s_title'],
		);
		/***********************
		convert to vars
		**********************/			
		$sectionLayout = $settings['layout_style'];
		$postType = $settings['post_type'];
		$cats = $settings['select_cats'];
		$nop = $settings['nop'];
		$sectionTitle = $settings['s_title'];
		if($postType == 'featured'){
			$args = array(
				'post_type' => 'post',
				'numberposts' => $nop,
				'cat' => $cats,
				'meta_query' => array(
					array(
						'key' => 'featured_post',
						'value' => '1',
						'compare' => '=='
					)
				),
			);
		}else{
			$args = array(
				'post_type' => 'post',
				'numberposts' => $nop,
				'cat' => $cats,
				
			);
		}
		global $redux_demo, $post;
		$betube_img_opti = true;
		$beTubedateFormat = get_option( 'date_format' );
		if (  class_exists( 'Redux' ) ) {   
		   $redux_demo = get_option( 'redux_demo' );
		   $betube_img_opti = $redux_demo['betube_img_opti'];
		}
		$sectionposts = new WP_Query($args);
		if ( $sectionposts->have_posts() ){
			?>
			<section class="btp_trending pb-3">
				<div class="container<?php if($sectionLayout == 'wide'){ echo "-fluid"; }?>">
					<div class="row">
						<div class="col-12">
							<div class="btp_section_head d-flex justify-content-between align-items-center mb-4">
								<h4 class="btp_section_head__title mb-0">
									<?php echo esc_html($sectionTitle); ?>
								</h4>
								<div class="btp_section_head__btns">
									<button class="btp_carousel_btn rounded carousel__btn_prev d-none d-md-inline-flex btn-outline-primary btn btn-sm">
										<i class="fas fa-angle-<?php if(is_rtl()){ echo "right";}else{ echo "left";}?> btp_carousel_btn__icon"></i>
									</button>
									<button class="btp_carousel_btn rounded carousel__btn_next d-none d-md-inline-flex btn-outline-primary btn btn-sm">
										<i class="fas fa-angle-<?php if(is_rtl()){ echo "left"; }else{echo "right"; }?> btp_carousel_btn__icon"></i>
									</button>
								</div><!--btp_section_head__btns-->
							</div><!--btp_section_head-->
						</div><!--col-12-->
						<div class="col-12">
							<div class="swiper-container border-bottom" data-slides-per-view="6" data-space-between="15" data-loop="true" data-free-mode="true" data-click="false" data-center-xs-slide="false" data-spvxs="auto" data-spvsm="auto" data-spvmd="auto" data-spvlg="auto" data-spvxl="auto">
								<div class="swiper-wrapper">
								<?php
								while ( $sectionposts->have_posts() ) : $sectionposts->the_post();
									$beTubeFeaturedPost = get_post_meta( $post->ID, 'featured_post', true );
									if($betube_img_opti == true){
										$thumbURL = betube_thumb_url($post->ID, 'betube-fslider');
									}else{
										$thumbURL = betube_thumb_url($post->ID, 'full');
									}
									$post_time = get_post_meta($post->ID, 'post_time', true);
									$post_quality = get_post_meta($post->ID, 'post_quality', true);
									$categories = get_the_category($post->ID);
									?>
									<div <?php post_class( 'swiper-slide btp_post_slide mb-4' ); ?>>
										<div class="card btp_post_card border-0 bg-transparent">
											<div class="btp_post_card__top mb-2">
												<?php if(!empty($thumbURL)){ ?>
												<img class="btp_post_card__img" src="<?php echo esc_url($thumbURL);?>" alt="<?php echo get_the_title($post->ID);?>">
												<?php } ?>
												<div class="card-img-overlay d-flex align-items-end justify-content-end">
													<div class="badge badge-dark rounded-0 mr-1">
														<?php echo esc_html($post_quality);?>
													</div>
													<div class="badge badge-dark rounded-0">
														<?php echo esc_html($post_time);?>
													</div>
												</div>
												<a href="<?php the_permalink($post->ID); ?>" class="btp_post_card__img_hover position-absolute d-flex text-decoration-none align-items-center justify-content-center">
													<i class="fas fa-play btp_post_card__img_hover_icon"></i>
												</a>
											</div><!--btp_post_card__top-->
											<h6 class="text-truncate">
												<a href="<?php the_permalink($post->ID); ?>" class="btp_post_card__title text-decoration-none">
													<?php echo get_the_title($post->ID); ?>
												</a>
											</h6>
											<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>" class="small btp_post_card__author text-decoration-none">
												<span class="btp_post_card__author_text">
												<?php the_author(); ?>
												</span>
												<i class="btp_post_card__author_icon fas fa-check-circle ml-1"></i>
											</a>
											<p class="mb-0">
												<?php if($betube_views_count == true){ ?>
												<small class="mr-2"><?php echo betube_get_post_views($post->ID); ?>&nbsp;<?php esc_html_e('views', 'betube');?></small>
												<?php } ?>
												<small>
												<?php echo get_the_date($beTubedateFormat, $post->ID); ?>
												</small>
											</p>
										</div><!--card-->
									</div><!--swiper-slide-->
								<?php endwhile;	?>	
								</div><!--swiper-wrapper-->
							</div><!--swiper-container-->
						</div><!--col-12-->
					</div><!--row-->
				</div><!--container-->
			</section>
		<?php
		}wp_reset_query();
	}
}