<?php
use Elementor\Plugin;
use Elementor\Controls_Manager;
class betube_videos_slider_styles extends \Elementor\Widget_Base {
	public function get_name() {
		return 'betube-videos-slider-styles';
	}
	public function get_title() {
		return esc_html__( 'Betube Videos Slider', 'betube-elementor' );
	}
	public function get_icon() {
		return 'eicon-slider-video';
	}
	public function get_categories() {
		return [ 'betube' ];
	}
	protected function register_controls() {
		$this->start_controls_section(
			'setting_section',
			[
				'label' => __( 'Setting', 'betube-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);		
		/*====Show WordPress Post categories ====*/
		$options = array();
		$args = array(
			'hide_empty' => false,
			'parent' => 0,
			'orderby' => 'name',
		);
		$categories = get_categories($args);
		if($categories){
			foreach ( $categories as $key => $category ) {
				$options[$category->term_id] = $category->name;
			}
		}
		unset($args);
		$this->add_control( 'select_cats', [
			'label'   => esc_html__( 'Select Categories', 'betube-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'multiple' => true,
			'options' => $options,
			'default' => '1',
		] );
		/*====Show WordPress Post categories ====*/		
		$this->add_control( 'orderby', [
			'label'   => esc_html__( 'Order by', 'betube-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'options' => [
				'date'=> esc_html__( 'Order by date', 'betube-elementor' ),
				'title'=> esc_html__( 'Order by title', 'betube-elementor' ),
				'views'=> esc_html__( 'Order by views', 'betube-elementor' ),
				'comment_count'=> esc_html__( 'Order by comments', 'betube-elementor' ),
				'rand'=> esc_html__( 'Order by random', 'betube-elementor' ),
			],
			'default' => 'rand',
		] );		
		$this->add_control(
            'nop',
            [
                'label' => __( 'Number of posts', 'betube-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'input_type' => 'text',
                'placeholder' => __( 'Enter a number', 'betube-elementore' ),
				'default' => '5',
            ]			
        );
		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings_for_display();
		$atts = array(
			'orderby' => $settings['orderby'],		
			'select_cats' => $settings['select_cats'],		
			'nop' => $settings['nop'],
		);
		/***********************
		convert to vars
		**********************/
		$orderby = $settings['orderby'];
		$cats = $settings['select_cats'];
		$nop = $settings['nop'];		
		if($orderby == 'views'){
			$args = array(
				'post_type' => 'post',
				'numberposts' => $nop,
				'cat' => $cats,
				'order' => 'DESC',
				'meta_key' => 'wpb_post_views_count',
				'orderby' => 'meta_value_num'
			);
		}else{
			$args = array(
				'post_type' => 'post',
				'numberposts' => $nop,
				'cat' => $cats,
				'order' => 'DESC',
				'orderby' => $orderby
			);
		}
		global $redux_demo, $post;
		$betube_img_opti = true;
		$betube_views_count = true;
		$betubeautoPlay = false;
		$beTubedateFormat = get_option( 'date_format' );
		if (  class_exists( 'Redux' ) ) {   
		   $redux_demo = get_option( 'redux_demo' );
		   $betube_img_opti = $redux_demo['betube_img_opti'];
		   $betube_views_count = $redux_demo['betube_views_count'];
		   $betubeautoPlay = $redux_demo['betube-vertical-slider'];
		}		
		$sectionposts = new WP_Query($args);
		if ( $sectionposts->have_posts() ){
			?>
			<section class="btp_main_slider mb-4">
				<div class="container-fluid">
					<div class="row">
						<div class="col-12">
							<div class="swiper-container" data-slides-per-view="3" data-space-between="0" data-loop="true" data-click="false" data-spvxs="1" data-spvsm="auto" data-spvmd="auto" data-spvlg="auto" data-spvxl="auto" data-free-mode="true" data-auto-play="<?php if($betubeautoPlay == true){echo "true"; }else{ echo "false"; }?>">
								<div class="swiper-wrapper">
									<?php
									while ( $sectionposts->have_posts() ) : $sectionposts->the_post();
										$post_quality = get_post_meta($post->ID, 'post_quality', true);
										if($betube_img_opti == true){
											$thumbURL = betube_thumb_url($post->ID, 'slider');
										}else{
											$thumbURL = betube_thumb_url($post->ID, 'full');
										}								
										?>
										<div class="swiper-slide btp_main_slider_slide">
											<div class="card border-0 text-white btp_main_card">
											<?php if(!empty($thumbURL)){ ?>
											<img class="btp_main_card__img img-fluid" src="<?php echo esc_url($thumbURL); ?>" alt="<?php echo get_the_title();?>">
											<?php } ?>
												<div class="card-img-overlay d-flex flex-column align-items-sm-start justify-content-center p-3 p-sm-5 btp_main_card__overlay">
													<h2 class="mb-2 mb-sm-0 btp_main_card__title font-weight-bold text-shadow text-break text-white">
														<?php echo get_the_title();?>
													</h2>
													<p class="btp_main_card__desc block_with_text text-shadow d-none d-sm-block text-break text-white" >
														<?php echo get_the_excerpt(); ?>
													</p>
													<div class="btp_main_card__actions mb-3">
														<a href="<?php the_permalink(); ?>" class="btn btn-danger font-weight-bold mr-2">
															<?php esc_html_e('Click here to watch', 'betube');?>
														</a>
														<span class="font-weight-bold text-shadow">
															<?php echo esc_html($post_quality);?>
														</span>
													</div>
												</div><!--card-img-overlay-->
											</div><!--card-->
										</div><!--swiper-slide-->
									<?php endwhile;	?>
								</div><!--swiper-wrapper-->
							</div>
						</div><!--col-12-->
					</div><!--row-->
				</div><!--container-->
			</section>
		<?php
		}wp_reset_query();
	}
}