<?php
use Elementor\Plugin;
use Elementor\Controls_Manager;
class betube_videos_styles extends \Elementor\Widget_Base {
	public function get_name() {
		return 'betube-videos-styles';
	}
	public function get_title() {
		return esc_html__( 'Betube Videos', 'betube-elementor' );
	}
	public function get_icon() {
		return 'eicon-video-playlist';
	}
	public function get_categories() {
		return [ 'betube' ];
	}
	protected function register_controls() {
		$this->start_controls_section(
			'setting_section',
			[
				'label' => __( 'Setting', 'betube-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control( 'layout_style', [
			'label'   => esc_html__( 'Section style', 'betube-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'options' => [
				'boxed'=> esc_html__( 'Boxed', 'betube-elementor' ),
				'wide'=> esc_html__( 'Wide', 'betube-elementor' ),
			],
			'default' => 'wide',
		] );
		/*====Show WordPress Post categories ====*/
		$options = array();
		$args = array(
			'hide_empty' => false,
			'parent' => 0,
			'orderby' => 'name',
		);
		$categories = get_categories($args);
		if($categories){
			foreach ( $categories as $key => $category ) {
				$options[$category->term_id] = $category->name;
			}
		}
		unset($args);
		$this->add_control( 'select_cats', [
			'label'   => esc_html__( 'Select Categories', 'betube-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'multiple' => true,
			'options' => $options,
			'default' => '1',
		] );
		/*====Show WordPress Post categories ====*/
		$this->add_control(
            's_title',
            [
                'label' => __( 'Section title', 'betube-elementor' ),
                'type' => Controls_Manager::TEXT,
                'input_type' => 'text',
                'placeholder' => __( 'Enter your title', 'betube-elementore' ),
				'default' => 'Latest Videos',
            ]
        );
		$this->add_control( 'orderby', [
			'label'   => esc_html__( 'Order by', 'betube-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'options' => [
				'date'=> esc_html__( 'Order by date', 'betube-elementor' ),
				'title'=> esc_html__( 'Order by title', 'betube-elementor' ),
				'views'=> esc_html__( 'Order by views', 'betube-elementor' ),
				'comment_count'=> esc_html__( 'Order by comments', 'betube-elementor' ),
				'rand'=> esc_html__( 'Order by random', 'betube-elementor' ),
			],
			'default' => 'rand',
		] );		
		$this->add_control(
            'nop',
            [
                'label' => __( 'Number of posts', 'betube-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'input_type' => 'text',
                'placeholder' => __( 'Enter a number', 'betube-elementore' ),
				'default' => '5',
            ]			
        );
		$this->add_control(
            's_url',
            [
                'label' => __( 'Section URL', 'betube-elementor' ),
                'type' => Controls_Manager::URL,
                'placeholder' => __( 'Enter your URL', 'betube-elementor' ),
                'show_external' => true,
				'default' => [
					'url' => 'https://google.com/',
					'is_external' => true,
					'nofollow' => true,
				],
            ]
        );
		$this->add_control(
            'btntxt',
            [
                'label' => __( 'View Button', 'betube-elementor' ),
                'type' => Controls_Manager::TEXT,
                'input_type' => 'text',
                'placeholder' => __( 'Replace button text', 'betube-elementor' ),
				'default' => 'View All',
            ]
        );
		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings_for_display();
		$atts = array(			
			'layout' => $settings['layout_style'],		
			'orderby' => $settings['orderby'],		
			'select_cats' => $settings['select_cats'],		
			'nop' => $settings['nop'],
			'btntxt' => $settings['btntxt'],
			's_title' => $settings['s_title'],
			's_url' => $settings['s_url'],
		);
		/***********************
		convert to vars
		**********************/			
		$sectionLayout = $settings['layout_style'];
		$orderby = $settings['orderby'];
		$cats = $settings['select_cats'];
		$nop = $settings['nop'];
		$sectionBtnTxt = $settings['btntxt'];
		$sectionTitle = $settings['s_title'];
		$sectionURL = $settings['s_url']['url'];
		if($orderby == 'views'){
			$args = array(
				'post_type' => 'post',
				'numberposts' => $nop,
				'cat' => $cats,
				'order' => 'DESC',
				'meta_key' => 'wpb_post_views_count',
				'orderby' => 'meta_value_num'
			);
		}else{
			$args = array(
				'post_type' => 'post',
				'numberposts' => $nop,
				'cat' => $cats,
				'order' => 'DESC',
				'orderby' => $orderby
			);
		}
		global $redux_demo, $post;
		$betube_img_opti = true;
		$betube_views_count = true;
		$beTubedateFormat = get_option( 'date_format' );
		if (  class_exists( 'Redux' ) ) {   
		   $redux_demo = get_option( 'redux_demo' );
		   $betube_img_opti = $redux_demo['betube_img_opti'];
		   $betube_views_count = $redux_demo['betube_views_count'];
		}		
		$latestposts = get_posts($args);
		if($latestposts){
			?>
			<section class="btp_lt_posts pb-3">
				<div class="container<?php if($sectionLayout == 'wide'){ echo "-fluid"; }?>">
					<div class="row">
						<div class="col-12">
							<div class="btp_section_head d-flex justify-content-between align-items-center mb-4">
								<h4 class="btp_section_head__title mb-0">
									<?php echo esc_html($sectionTitle); ?>
								</h4>
								<div class="btp_section_head__btns">
									<a href="<?php echo esc_url($sectionURL); ?>" class="text-primary font-weight-bold mr-2 text-decoration-none">
										<?php echo esc_html($sectionBtnTxt); ?>
									</a>
								</div><!--btp_section_head__btns-->
							</div><!--btp_section_head-->
						</div><!--col-12-->
					</div><!--row-->
					<div class="btp_lt_posts__container d-grid align-items-center justify-content-start border-bottom pb-4">
						<?php
						foreach ( $latestposts as $post ){
							setup_postdata( $post );
							if($betube_img_opti == true){
								$thumbURL = betube_thumb_url($post->ID, 'betube-thumbnail');
							}else{
								$thumbURL = betube_thumb_url($post->ID, 'full');
							}						
							$post_time = get_post_meta($post->ID, 'post_time', true);
							$post_quality = get_post_meta($post->ID, 'post_quality', true);
							?>
							<div class="card btp_post_card btp_post_card_lt border-0 bg-transparent">
								<div class="btp_post_card__top mb-3">
									<?php if(!empty($thumbURL)){ ?>
									<img class="btp_post_card__img" src="<?php echo esc_url($thumbURL);?>" alt="<?php echo get_the_title($post->ID);?>">
									<?php } ?>
									<div class="card-img-overlay d-flex align-items-end justify-content-end">
										<div class="badge badge-dark rounded-0 mr-1">
											<?php echo esc_html($post_quality);?>
										</div>
										<div class="badge badge-dark rounded-0">
											<?php echo esc_html($post_time);?>
										</div>
									</div>
									<a href="<?php the_permalink($post->ID); ?>" class="btp_post_card__img_hover position-absolute d-flex text-decoration-none align-items-center justify-content-center">
										<i class="fas fa-play btp_post_card__img_hover_icon"></i>
									</a>
								</div><!--btp_post_card__top-->
								<h6 class="text-truncate">
									<a href="<?php the_permalink($post->ID); ?>" class="btp_post_card__title text-decoration-none">
										<?php echo get_the_title($post->ID); ?>
									</a>
								</h6>
								<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>" class="small btp_post_card__author text-decoration-none">
									<span class="btp_post_card__author_text">
									<?php the_author(); ?>
									</span>
									<i class="btp_post_card__author_icon fas fa-check-circle ml-1"></i>
								</a>
								<p class="mb-0">
									<?php if($betube_views_count == true){ ?>
									<small class="mr-2"><?php echo betube_get_post_views($post->ID); ?>&nbsp;<?php esc_html_e('views', 'betube');?></small>
									<?php } ?>
									<small><?php echo get_the_date($beTubedateFormat, $post->ID); ?></small>
								</p>
							</div><!--card-->
						<?php }	?>
					</div><!--btp_lt_posts__container-->
				</div><!--container-->
			</section>
		<?php
		}wp_reset_postdata();
	}
}