<?php
/**
 * The template for displaying comments
 * This is the template that displays the area of the page that contains both the current comments and the comment form
 * Learn more: http://codex.wordpress.org/Template_Hierarchy
 * @package betube
 * @since betube 3.0
 */
/*==========================
If the current post is protected by a password and
the visitor has not yet entered the password we will
return early without loading the comments.
===========================*/
if ( post_password_required() ) {
	return;
}
$discussion = betubepro_discussion_data();
?>
<div id="comments" class="<?php echo comments_open() ? 'comments-area' : 'comments-area comments-closed'; ?>">
	<div class="<?php echo esc_attr($discussion->responses > 0 ? 'comments-title-wrap' : 'comments-title-wrap no-responses'); ?>">
		<h5 class="comments-title">
		<?php
		if ( comments_open() ) {
			if ( have_comments() ) {
				esc_html_e( 'Join the Conversation', 'betube' );
			} else {
				esc_html_e( 'Leave a comment', 'betube' );
			}
		} else {
			if ( '1' == $discussion->responses ) {
				/* translators: %s: post title */
				printf( _x( 'One reply on &ldquo;%s&rdquo;', 'comments title', 'betube' ), get_the_title() );
			} else {
				printf(
					/* translators: 1: number of comments, 2: post title */
					_nx(
						'%1$s reply on &ldquo;%2$s&rdquo;',
						'%1$s replies on &ldquo;%2$s&rdquo;',
						$discussion->responses,
						'comments title',
						'betube'
					),
					number_format_i18n( $discussion->responses ),
					get_the_title()
				);
			}
		}
		?>
		</h5><!-- .comments-title -->
		<?php 
		if ( have_comments() && comments_open() ) {
			$has_responses = $discussion->responses > 0;
			/*==========================
			Only show discussion meta information
			when comments are open and available.
			===========================*/
			if ( $has_responses ) {
				/* translators: %1(X comments)$s */
				$meta_label = sprintf( _n( '%d Comment', '%d Comments', $discussion->responses, 'betube' ), $discussion->responses );
			} else {
				$meta_label = __( 'No comments', 'betube' );
			}
			?>
			<div class="discussion-meta">
				<?php 
				if ( $has_responses ) {
					betubepro_discussion_avatars_list($discussion->authors);
				}
				?>
				<p class="discussion-meta-info">
					<span><?php echo esc_html( $meta_label ); ?></span>
				</p>
			</div>
			<?php
		}
		?>
	</div>
	<?php 
	if ( have_comments() ){
		if ( comments_open() ) {
			$order = 'desc';
			if ( true === $order || strtolower( $order ) === strtolower( get_option( 'comment_order', 'asc' ) ) ) {
				comment_form(
					array(
						'logged_in_as' => null,
						'title_reply'  => null,
					)
				);
			}
		}?>
		<ol class="comment-list">
			<?php
			wp_list_comments(
				array(
					'avatar_size' => 150,
					'short_ping'  => true,
					'style'       => 'ol',
				)
			);
			comment_form(
				array(
					'logged_in_as' => null,
					'title_reply'  => null,
				)
			);
			?>
		</ol>
		<?php
		if ( have_comments() ){
			$prev_icon     = '<i class="fas fa-chevron-left"></i>';
			$next_icon     = '<i class="fas fa-chevron-right"></i>';
			the_comments_navigation(
				array(
					'prev_text' => sprintf( '%s <span class="nav-prev-text"><span class="primary-text">%s</span> <span class="secondary-text">%s</span></span>', $prev_icon, __( 'Previous', 'betube' ), __( 'Comments', 'betube' ) ),
					'next_text' => sprintf( '<span class="nav-next-text"><span class="primary-text">%s</span> <span class="secondary-text">%s</span></span> %s', __( 'Next', 'betube' ), __( 'Comments', 'betube' ), $next_icon ),
				)
			);
		}
	}else{
		comment_form(
			array(
				'logged_in_as' => null,
				'title_reply'  => null,
			)
		);
	}
	
	?>
</div><!--comments-->