<?php
/*==========================
 * BeTubePro functions and definitions.
 * @package WordPress
 * @subpackage BeTubePro
 * @since BeTubePro 1.0
===========================*/
if(function_exists('load_theme_textdomain')){
	load_theme_textdomain( 'betube', get_template_directory() . '/languages' );
}
/*==========================
 BeTubePro : All Required Files
 @since 1.0
===========================*/
require get_template_directory() . '/assets/enqueue-styles-script.php';
require get_template_directory() . '/assets/color-class.php';
require get_template_directory() . '/assets/required-plugins.php';
require get_template_directory() . '/assets/theme-support.php';
/*==========================
 beTube : Video Thumbnails
 @since 1.0
===========================*/
if (!function_exists('betube_video_thumbnail_markup')){	
	function betube_video_thumbnail_markup( $markup, $post_id ) {
		$markup .= ' ' . get_post_meta($post_id, 'jtheme_video_code', true);
		$markup .= ' ' . get_post_meta($post_id, 'jtheme_video_url', true);
		return $markup;
	}
	add_filter( 'video_thumbnail_markup', 'betube_video_thumbnail_markup', 10, 2 );
}
/*==========================
 beTube : Remove PMP login
 @since 1.0
===========================*/

/*==========================
 Load Theme options from Redux Framework
===========================*/
if ( class_exists( 'Redux' ) && file_exists( get_template_directory() . '/assets/betube-options.php' ) ) {
	require_once( get_template_directory() . '/assets/betube-options.php' );
}
/*==========================
 beTube : Tags Widget Limit
 Register tag cloud filter callback
 @since 1.0
===========================*/
if (!function_exists('betube_tag_widget_limit')){	
	add_filter('widget_tag_cloud_args', 'betube_tag_widget_limit');
	function betube_tag_widget_limit($args){
		global $redux_demo;
		$tagsnumber= $redux_demo['tags_limit'];
		if(isset($args['taxonomy']) && $args['taxonomy'] == 'post_tag'){
		  $args['number'] = $tagsnumber; //Limit number of tags
		}
		return $args;
	}
}
/*==========================
 Custom admin scripts
===========================*/
if (!function_exists('betubepro_admin_scripts')){
	function betubepro_admin_scripts() {
		wp_enqueue_media();
	}
}
/*==========================
 beTube : get_avatar_url
 @since 1.0
===========================*/
if (!function_exists('betube_get_avatar_url')){
	function betube_get_avatar_url($author_id, $size){
		$get_avatar = get_avatar( $author_id, $size );
		$matches = array();     
		preg_match('/(?<!_)src=([\'"])?(.*?)\\1/',$get_avatar, $matches);	
		return ( $matches[2] );
	}
}
/*==========================
 beTube : Allow User Uploads
 @since 1.0
===========================*/
if (!function_exists('betube_allow_users_uploads')){
	function betube_allow_users_uploads() {
		$contributor = get_role('contributor');
		$contributor->add_cap('upload_files');
		$contributor->add_cap('delete_published_posts');
		$subscriber = get_role('subscriber');
		$subscriber->add_cap('upload_files');
		$subscriber->add_cap('delete_published_posts');
	}
	add_action('admin_init', 'betube_allow_users_uploads');
}
if (!function_exists('betube_allow_contributor_uploads')){
	if ( current_user_can('subscriber') || current_user_can('contributor') && !current_user_can('upload_files') ) {
		add_action('admin_init', 'betube_allow_contributor_uploads');
	}
	function betube_allow_contributor_uploads() {	
		$contributor = get_role('contributor');
		$contributor->add_cap('upload_files');		
		$subscriber = get_role('subscriber');
		$subscriber->add_cap('upload_files');	
	}
}
/*==========================
 beTube : betube_devplus_attachments_wpquery_where
 @since 1.0
===========================*/
if (!function_exists('betube_devplus_attachments_wpquery_where')){
	add_filter( 'posts_where', 'betube_devplus_attachments_wpquery_where' );
	function betube_devplus_attachments_wpquery_where( $where ){
		global $current_user;
		if ( !current_user_can( 'administrator' ) ) {
			if( is_user_logged_in() ){
				// we spreken over een ingelogde user
				if( isset( $_POST['action'] ) ){
					// library query
					if( $_POST['action'] == 'query-attachments' ){
						$where .= ' AND post_author='.$current_user->data->ID;
					}
				}
			}
		}
		return $where;
	}
}
/*==========================
 beTube : Post Views
 @since 1.0
===========================*/
if (!function_exists('betube_set_post_views')){
	function betube_set_post_views($postID) {
		$count_key = 'wpb_post_views_count';
		$count = get_post_meta($postID, $count_key, true);
		if($count==''){
			$count = 0;
			delete_post_meta($postID, $count_key);
			add_post_meta($postID, $count_key, '0');
		}else{
			$count++;
			update_post_meta($postID, $count_key, $count);
		}
	}
}
if (!function_exists('betube_track_post_views')){
	function betube_track_post_views ($post_id) {
		if ( !is_single() ) return;
		if ( empty ( $post_id) ) {
			global $post;
			$post_id = $post->ID;    
		}
		betube_set_post_views($post_id);
	}
}
if (!function_exists('betube_get_post_views')){
	function betube_get_post_views($postID){
		$count_key = 'wpb_post_views_count';
		$count = get_post_meta($postID, $count_key, true);
		if($count==''){
			delete_post_meta($postID, $count_key);
			add_post_meta($postID, $count_key, '0');
			return "0";
		}
		return $count;
	}
}
/*==========================
 beTube : Post Thumb URL
 @since 1.0
===========================*/
if (!function_exists('betube_thumb_url')){
	function betube_thumb_url($post_id, $size){
		global $post, $redux_demo;	
		$default = "";
		$thumb_url = "";
		
		if(empty($post_id)){
			$post_id = $post->ID;	
		}		
		/* Check if this video has a feature image */
		if(has_post_thumbnail($post_id)){
			$thumb_url = get_the_post_thumbnail_url($post_id, $size);		
		}
		/* If no feature image, try to get thumbnail by "Video Thumbnails" plugin */
		if(empty($thumb_url) && function_exists('get_video_thumbnail')) {
			$video_thumbnail = get_video_thumbnail($post_id, $size);
			if(!is_wp_error($video_thumbnail)){
				$thumb_url = $video_thumbnail;
			}
		}

		/* If this is a video by jplayer, try to get thumbnail from video_posts */
		if(empty($thumb_url) && $poster = get_post_meta($post_id, 'jtheme_video_poster', true)){
			$thumb_url = get_post_meta($post_id, 'jtheme_video_poster', true);
		}
		/* If still no image or is wp error, define default image */
		if(empty($thumb_url) || is_wp_error($thumb_url)) {
			if($default === false || $default === 0){
				return false;
			}
			$thumb_url = '';
		}
		return $thumb_url;
	}
}
/*==========================
 beTube : Facebook Meta Function 
 @since 1.0
 ===========================*/
if (!function_exists('betube_facebook_tags')){
	function betube_facebook_tags(){
		$description = get_bloginfo('description');
		global $redux_demo;
		$beTubeFBAPPID = $redux_demo['betubefbappid'];
		$beTubeFBPlay = $redux_demo['betube-play-on-facebook'];
		if(is_author()){
			$description = get_the_author_meta( 'description' );
			if($description==''){$description = get_bloginfo('description');}
		}
		if(is_single()){
			global $post;		
			$betubeExcerpt = $post->post_excerpt;
			if(empty($betubeExcerpt)){
				$description = $post->post_content;
			}else{
				$description = $betubeExcerpt;
			}
			$betubePostIMG = wp_get_attachment_url(get_post_thumbnail_id($post->ID));
			if(empty($betubePostIMG)){
				$betubeOGIMG = trim(get_post_meta($post->ID, 'jtheme_video_file', true));
			}else{
				$betubeOGIMG = $betubePostIMG;
			}
			
			$url_video = get_post_meta($post->ID,'jtheme_video_url',true);
			if($url_video==''){$url_video = get_permalink($post->ID);}		
			if($beTubeFBPlay == 1){?>
				<meta property="og:title" content="<?php echo get_the_title($post->ID);?>"/>
				<meta property="og:type" content="website" />
				<meta property="og:image" content="<?php echo esc_url($betubeOGIMG); ?>"/>
				<meta property="og:url" content="<?php echo get_permalink($post->ID);?>"/>
				<meta property="og:site_name" content="<?php echo get_bloginfo('name');?>"/>        
				<meta property="og:description" content="<?php echo strip_tags($description);?>"/>
				<?php if($beTubeFBAPPID){ ?>
					<meta property="fb:app_id" content="<?php echo esc_attr($beTubeFBAPPID); ?>" />
				<?php }?>
			<?php }else{ ?>
				<meta property="og:title" content="<?php echo get_the_title($post->ID);?>"/>
				<meta property="og:type" content="<?php echo get_post_format($post->ID);?>"/>
				<meta property="og:image" content="<?php echo esc_url($betubeOGIMG); ?>"/>
				<meta property="og:url" content="<?php echo esc_url($url_video);?>"/>
				<meta property="og:site_name" content="<?php echo get_bloginfo('name');?>"/>
				<meta property="og:description" content="<?php echo strip_tags($description);?>"/>
				<?php if($beTubeFBAPPID){ ?>
					<meta property="fb:app_id" content="<?php echo esc_attr($beTubeFBAPPID);?>" />
				<?php }?>
			<?php 
			}
			if(get_post_format($post->ID) == 'video'){
				$video_file = get_post_meta($post->ID,'jtheme_video_file',true);
				if($video_file != ''){
					$urls = explode(PHP_EOL,$video_file);
					?>
					<meta property="og:video" content="<?php echo esc_url($urls[0]);?>"/>
					<meta property="og:video:secure_url" content="<?php echo esc_url($url_video);?>"/>
					<?php
				}
			
			?>
			<?php }?>
	<?php
		}
		?>
		<meta property="description" content="<?php echo strip_tags($description);?>"/>
		<?php
	}
}
/*==========================
 beTube : Insert attachments front end
 @since 1.0
===========================*/
if (!function_exists('betube_insert_attachment')){
	function betube_insert_attachment($file_handler,$post_id,$setthumb='false') {
		if ($_FILES[$file_handler]['error'] !== UPLOAD_ERR_OK) __return_false();
		require_once(ABSPATH . "wp-admin" . '/includes/image.php');
		require_once(ABSPATH . "wp-admin" . '/includes/file.php');
		require_once(ABSPATH . "wp-admin" . '/includes/media.php');
		$attach_id = media_handle_upload( $file_handler, $post_id );
		return $attach_id;
	}
}
/*==========================
 beTube : betube User profile image upload
 @since 1.0
 ===========================*/
if (!function_exists('betube_insert_userIMG')){
	function betube_insert_userIMG($file_handler){
		if ($_FILES[$file_handler]['error'] !== UPLOAD_ERR_OK) __return_false();
		require_once(ABSPATH . "wp-admin" . '/includes/image.php');
		require_once(ABSPATH . "wp-admin" . '/includes/file.php');
		require_once(ABSPATH . "wp-admin" . '/includes/media.php');
		$attach_id = media_handle_upload($file_handler, $post_id = null);	
		return $attach_id;
	}
}
/*==========================
 beTube : betube User profile image link
 @since 1.0
===========================*/
if (!function_exists('betube_get_image_url')){
	function betube_get_image_url($attach_id){
		$sourceURL = wp_get_attachment_image_src($attach_id, $size='full');
		$profileURL = $sourceURL[0];
		return $profileURL;
	}
}
/*==========================
 beTube : Get Template URL with template name.
 @since 2.0.5
 ===========================*/
if (!function_exists('betube_get_template_url')) {
	function betube_get_template_url($templatename){
		$url = '';
		if(!empty($templatename)){
			$archive_page = get_pages(
			array(
					'meta_key' => '_wp_page_template',
					'meta_value' => $templatename,
					'suppress_filters' => false,
				)
			);
			if($archive_page){
				$pageID = $archive_page[0]->ID;
				$url = get_permalink($pageID);
			}
		}		
		return $url;
	}
}
/*==========================
 beTube : categories Custom Fields
 @since 3.0
===========================*/
if (!function_exists('betube_my_category_fields')) {
	add_action( 'category_add_form_fields', 'betube_my_category_fields' );
	function betube_my_category_fields(){
		?>
		<div class="form-field term-name-wrap">
			<label for="">
				<?php esc_html_e( 'Category Thumbnail', 'betube' ); ?>
			</label>
			<div style="width: 100%;">
				<img id="your_image_url_img" src="" style="float: left; margin-bottom: 20px; width:100%;">
			</div>
			<input id="your_image_url" type="hidden" size="36" name="your_image_url" style="max-width: 200px; margin-top: 10px;">
			<input id="your_image_url_button_remove" class="button" type="button" value="Remove" style="max-width: 140px; margin-top: 10px; display: none;">
			<input id="your_image_url_button" class="button" type="button" value="Upload Image" style="max-width: 140px; margin-top: 10px;">
		</div>
		<?php
	}
}
if (!function_exists('betube_category_meta_edit')) {
	add_action( 'category_edit_form_fields', 'betube_category_meta_edit' );
	function betube_category_meta_edit($term){
		$your_image_url  = get_term_meta( $term->term_id, 'your_image_url', true);
		?>
		<tr class="form-field term-name-wrap">
			<th scope="row">
				<label>
					<?php esc_html_e('Category Thumbnail', 'betube'); ?>
				</label>
			</th>
			<td>				
				<div style="width: 100%; float: left;">
					<img id="your_image_url_img" src="<?php echo esc_url($your_image_url);?>" style="float: left; margin-bottom: 20px;">
				</div>				
				<input id="your_image_url" type="hidden" size="36" name="your_image_url" style="max-width: 200px; margin-top: 10px;" value="<?php echo esc_url($your_image_url);?>">
				<input id="your_image_url_button_remove" class="button" type="button" value="Remove" style="max-width: 140px; margin-top: 10px; <?php if(empty($your_image_url)){ ?> display: none; <?php } ?>">
				<input id="your_image_url_button" class="button" type="button" value="Upload Image" style="max-width: 140px; margin-top: 10px; <?php if(!empty($your_image_url)){ ?> display: none; <?php } ?>">
			</td>
		</tr>
		<?php
	}
}
if (!function_exists('betube_update_my_category_fields')) {
	function betube_update_my_category_fields($term_id) {
		if(isset($_POST['taxonomy'])){	
			if($_POST['taxonomy'] == 'category'):
				$old_value = '';
				if(isset($_POST['your_image_url'])){					
					update_term_meta( $term_id, 'your_image_url', $_POST['your_image_url']);
				}else{
					delete_term_meta( $term_id, 'your_image_url' );
				}
			endif;
		}
	}
}
if (!function_exists('betubepro_posted_on')) {
	function betubepro_posted_on(){
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
		}

		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);

		printf(
			'<a class="mr-3" href="%2$s" rel="bookmark">%1$s%3$s</a>',			
			'<i class="fas fa-calendar-alt mr-2"></i>',			
			esc_url( get_permalink() ),
			$time_string
		);
	}
}
if (!function_exists('betubepro_posted_ago')) {
	function betubepro_posted_ago($postID){
		$beTubedateFormat = get_option( 'date_format' );
		$post_date = get_the_time('U', $postID);
		$delta = time() - $post_date;
		if ( $delta < 60 ) {
			$postTime = esc_html__( 'Less than a minute ago', 'betube' );
		}elseif ($delta > 60 && $delta < 120){
			$postTime = esc_html__( 'About a minute ago', 'betube' );
		}elseif ($delta > 120 && $delta < (60*60)){
			$postTime = strval(round(($delta/60),0)).esc_html__( 'minutes ago', 'betube' );
		}elseif ($delta > (60*60) && $delta < (120*60)){
			$postTime = esc_html__( 'About an hour ago', 'betube' );
		}elseif ($delta > (120*60) && $delta < (24*60*60)){
			$postTime = strval(round(($delta/3600),0)).esc_html__( 'hours ago', 'betube' );
		}else{
			$postTime = get_the_date($beTubedateFormat, $postID);
		}
		return $postTime;
	}
}
/*==========================
betube: Get Comments Data
===========================*/
if (!function_exists('betubepro_discussion_data')){
	function betubepro_discussion_data(){
		static $discussion, $post_id;
		$current_post_id = get_the_ID();
		if ( $current_post_id === $post_id ) {
			return $discussion; /* If we have discussion information for post ID, return cached object */
		} else {
			$post_id = $current_post_id;
		}
		$comments = get_comments(
		array(
				'post_id' => $current_post_id,
				'orderby' => 'comment_date_gmt',
				'order'   => get_option( 'comment_order', 'asc' ), /* Respect comment order from Settings » Discussion. */
				'status'  => 'approve',
				'number'  => 20, /* Only retrieve the last 20 comments, as the end goal is just 6 unique authors */
			)
		);
		$authors = array();
		foreach ( $comments as $comment ) {
			$authors[] = ( (int) $comment->user_id > 0 ) ? (int) $comment->user_id : $comment->comment_author_email;
		}
		$authors    = array_unique( $authors );
		$discussion = (object) array(
			'authors'   => array_slice( $authors, 0, 6 ),           /* Six unique authors commenting on the post. */
			'responses' => get_comments_number( $current_post_id ), /* Number of responses. */
		);
		return $discussion;
	}
}
if (!function_exists('betubepro_get_user_avatar_markup')){
	function betubepro_get_user_avatar_markup($id_or_email = null){
		if ( ! isset( $id_or_email ) ) {
			$id_or_email = get_current_user_id();
		}
		return sprintf( '<div class="comment-user-avatar comment-author vcard">%s</div>', get_avatar( $id_or_email, 150 ) );
	}
}
if (!function_exists('betubepro_discussion_avatars_list')){
	function betubepro_discussion_avatars_list($comment_authors){
		if ( empty( $comment_authors ) ) {
			return;
		}
		echo '<ol class="discussion-avatar-list">', "\n";
		foreach ( $comment_authors as $id_or_email ) {
			printf(
				"<li>%s</li>\n",
				betubepro_get_user_avatar_markup( $id_or_email )
			);
		}
		echo '</ol><!-- .discussion-avatar-list -->', "\n";
	}
}
/*==========================
betube: Add Custom Class to Table
===========================*/
if (!function_exists('betubepro_custom_classes')){
	add_filter( 'the_content', 'betubepro_custom_classes');
	function betubepro_custom_classes($content){	
		$content = str_replace('<table', '<table class="table"', $content);
		return $content;
	}
}
/*==========================
betube: Remove pages from search query
===========================*/
if (!function_exists('betubepro_search_filter')){
	function betubepro_search_filter(){
		global $wp_query;		
		if ($wp_query->is_search) {
			$wp_query->set('post_type', 'post');
		}		
		return $wp_query;
	}
	add_filter('pre_get_posts','betubepro_search_filter');
}
/*==========================
betube: Set Post expert
===========================*/
if (!function_exists('betubepro_excerpt_length')){
	function betubepro_excerpt_length(){
		if ( get_post_type( get_the_ID() ) == 'post' ){
			return 100;
		}elseif ( get_post_type( get_the_ID() ) == 'blog' ){
			return 60;
		}
	}
	add_filter('excerpt_length','betubepro_excerpt_length');
}
if (!function_exists('betube_excerpt_more')){
	function betube_excerpt_more( $more ) {
		return '';
	}
	add_filter('excerpt_more', 'betube_excerpt_more');
}