<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * e.g., it puts together the home page when no home.php file exists.
 *
 * Learn more: {@link https://codex.wordpress.org/Template_Hierarchy}
 *
 * @package WordPress
 * @subpackage betube
 * @since betube 3.0
 */
get_header(); ?>
<?php 
$beTubedateFormat = get_option( 'date_format' );
$betube_img_opti = true;
$betube_boxed= 'boxed';
if(isset($redux_demo)){
	$betube_boxed = $redux_demo['betube_boxed'];
	$betube_img_opti = $redux_demo['betube_img_opti'];
}
if (!is_home() || !is_front_page()) { ?>
<div class="container<?php if($betube_boxed == 'wide'){ echo "-fluid"; }?>">
	<div class="row">
		<div class="col-12">
			<!-- breadcrumb -->
			<nav aria-label="breadcrumb">
				<ol class="breadcrumb bg-transparent border-bottom mb-4 rounded-0 pl-0">
					<li class="breadcrumb-item">
						<a href="<?php echo esc_url(home_url()); ?>" class="breadcrumb-link">
							<?php esc_html_e( 'Home', 'betube' ); ?>
						</a>
					</li>
					<li class="breadcrumb-item active" aria-current="page"><?php the_archive_title(); ?></li>
				</ol>
			</nav>
		</div><!--col-12-->
	</div><!--row-->
</div><!--container-->
<?php } ?>
<section class="btp_inner_page pb-5">
	<div class="container<?php if($betube_boxed == 'wide'){ echo "-fluid"; }?>">
		<div class="row">
		<?php if ( have_posts() ) : ?>
			<div class="<?php if ( is_active_sidebar( 'pages' ) ) {echo "col-lg-8 col-xl-9";}else{ echo "col-12 col-lg-9 mx-auto"; }?>">
				<div class="row">
					<?php while ( have_posts() ) : the_post(); ?>
					<div class="col-12">						
						<div class="card border-0 btp_blog_card mb-5 btp_index_card shadow rounded p-5 <?php if(is_sticky()){echo "btp_index_sticky";}?>">
						<p>
							<a href="<?php the_permalink(); ?>"><?php echo get_the_date($beTubedateFormat, $post->ID); ?></a>
							<?php $categories = get_the_category($post->ID); ?>
							<?php if($categories){ ?>
							<span><?php esc_html_e('in', 'betube');?></span>
							<?php foreach ($categories as $category){ ?>
								<a class="btp_index_cat" href="<?php echo esc_url(get_category_link($category->term_id));?>">
									<?php echo esc_html($category->name); ?>
								</a>
							<?php } ?>
							<?php } ?>
						</p>
						<h2 class="text-break">
							<a href="<?php the_permalink(); ?>" class="text-decoration-none btp_blog_card__title">
							<?php echo get_the_title();?>
							</a>
						</h2>
						<div class="d-flex btp_blog_card__footer mb-3">
							<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>" class="small text-decoration-none btp_blog_card__link">
								<i class="fas fa-user-circle mr-1"></i>
								<span><?php the_author(); ?></span>
							</a>
							<a href="<?php the_permalink(); ?>" class="small text-decoration-none ml-3 btp_blog_card__link">
								<i class="far fa-comment mr-1"></i>
								<span><?php echo comments_number(); ?></span>
							</a>
						</div><!--btp_blog_card__footer-->
						<?php if( has_post_thumbnail()){ ?>
							<a href="<?php the_permalink(); ?>">
								<img class="img-fluid mb-3" src="<?php echo get_the_post_thumbnail_url( $post->ID); ?>" alt="<?php echo get_the_title();?>">
							</a>
						<?php } ?>	
						<?php the_excerpt(); ?>						
						<a class="mt-2 btn btn-outline-primary" href="<?php the_permalink(); ?>"><?php esc_html_e('Read more', 'betube');?></a>
						</div><!--card-->
					</div>
					<?php endwhile; ?>
				</div><!--row-->
				<div class="row">
					<div class="col">
						<?php
						the_posts_pagination(
							array(
								'mid_size'  => 2,
								'prev_text' => __( 'Back', 'betube' ),
								'next_text' => __( 'Onward', 'betube' ),
							)
						);
						?>
					</div>
				</div>
			</div><!--col-lg-8-->
			<?php if ( is_active_sidebar( 'pages' ) || is_active_sidebar( 'blog' )) { ?>
			<div class="col-lg-4 col-xl-3">
				<div class="btp_sidebar">
					<?php
					if ( is_post_type_archive( 'blog' ) || is_tax('blog_category')) {
						dynamic_sidebar('blog');
					}else{
						dynamic_sidebar('pages');
					}
					?>
				</div><!--btp_sidebar-->
			</div><!--col-lg-4-->
			<?php } ?>
		<?php else : ?>
			<div class="col-lg-12">
				<div class="row">
					<?php 
					if ( is_home() && current_user_can( 'publish_posts' ) ){
						printf(
							'<p>' . wp_kses(			
								__( 'Ready to publish your first post? <a href="%1$s">Get started here</a>.', 'betube' ),
								array(
									'a' => array(
										'href' => array(),
									),
								)
							) . '</p>',
							esc_url( admin_url( 'post-new.php' ) )
						);
					}else{
						esc_html_e('No Content', 'betube');
					}							
					?>
				</div>
			</div>
		<?php endif; ?>
		</div><!--row-->
	</div><!--container-->
</section>
<?php get_footer(); ?>