<?php
/**
 * The file used for tags
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * e.g., it puts together the home page when no home.php file exists.
 *
 * Learn more: {@link https://codex.wordpress.org/Template_Hierarchy}
 *
 * @package WordPress
 * @subpackage betube
 * @since betube 3.0
 */
get_header(); ?>
<?php 
$beTubedateFormat = get_option( 'date_format' );
$betube_img_opti = true;
$betube_boxed= 'boxed';
$betube_views_count = true;
if(isset($redux_demo)){
	$betube_boxed = $redux_demo['betube_boxed'];
	$betube_img_opti = $redux_demo['betube_img_opti'];
	$betube_views_count = $redux_demo['betube_views_count'];
}
?>
<div class="container<?php if($betube_boxed == 'wide'){ echo "-fluid"; }?>">
	<div class="row">
		<div class="col-12">
			<!-- breadcrumb -->
			<nav aria-label="breadcrumb">
				<ol class="breadcrumb bg-transparent border-bottom mb-4 rounded-0 pl-0">
					<li class="breadcrumb-item">
						<a href="<?php echo esc_url(home_url()); ?>" class="breadcrumb-link">
							<?php esc_html_e( 'Home', 'betube' ); ?>
						</a>
					</li>
					<li class="breadcrumb-item active" aria-current="page"><?php the_archive_title(); ?></li>
				</ol>
			</nav>
		</div><!--col-12-->
	</div><!--row-->
</div><!--container-->
<section class="btp_inner_page pb-5">
	<div class="container<?php if($betube_boxed == 'wide'){ echo "-fluid"; }?>">
		<div class="row">
		<?php if ( have_posts() ) : ?>
			<div class="<?php if ( is_active_sidebar( 'pages' ) ) {echo "col-lg-8 col-xl-9";}else{ echo "col-12 col-lg-9 mx-auto"; }?>">				
				<div class="btp_lt_posts__container btp_lt_posts__container_box d-grid align-items-center justify-content-start border-0">
					<?php while ( have_posts() ) : the_post(); ?>
					<?php										
					if($betube_img_opti == true){
						$thumbURL = betube_thumb_url($post->ID, 'betube-fslider');
					}else{
						$thumbURL = betube_thumb_url($post->ID, 'full');
					}
					
					$post_time = get_post_meta($post->ID, 'post_time', true);
					$post_quality = get_post_meta($post->ID, 'post_quality', true);
					?>
					<div class="card btp_post_card btp_post_card_lt border-0 bg-transparent mr-1 mb-4 <?php if(is_sticky()){echo "btp_index_sticky";}?>">
						<div class="btp_post_card__top mb-2">
							<?php if(!empty($thumbURL)){ ?>
							<img class="btp_post_card__img" src="<?php echo esc_url($thumbURL);?>" alt="<?php echo get_the_title();?>">
							<?php } ?>
							<div class="card-img-overlay d-flex align-items-end justify-content-end">
								<div class="badge badge-dark rounded-0 mr-1">
									<?php echo esc_html($post_quality);?>
								</div>
								<div class="badge badge-dark rounded-0">
									<?php echo esc_html($post_time);?>
								</div>
							</div>
							<a href="<?php the_permalink(); ?>" class="btp_post_card__img_hover position-absolute d-flex text-decoration-none align-items-center justify-content-center">
								<i class="fas fa-play btp_post_card__img_hover_icon"></i>
							</a>
						</div><!--btp_post_card__top-->
						<h6 class="text-truncate">
							<a href="<?php the_permalink(); ?>" class="btp_post_card__title text-decoration-none">
								<?php echo get_the_title(); ?>
							</a>
						</h6>
						<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>" class="small btp_post_card__author text-decoration-none">
							<span class="btp_post_card__author_text">
							<?php the_author(); ?>
							</span>
							<i class="btp_post_card__author_icon fas fa-check-circle ml-1"></i>
						</a>
						<p class="mb-0">
							<?php if($betube_views_count == true){ ?>
							<small class="mr-2"><?php echo betube_get_post_views($post->ID); ?>&nbsp;<?php esc_html_e('views', 'betube');?></small>
							<?php } ?>
							<small><?php echo get_the_date($beTubedateFormat, $post->ID); ?></small>
						</p>
					</div><!--card-->	
					<?php endwhile; ?>
				</div><!--btp_lt_posts__container-->
				<div class="row">
					<div class="col">
						<?php
						the_posts_pagination(
							array(
								'mid_size'  => 2,
								'prev_text' => __( 'Back', 'betube' ),
								'next_text' => __( 'Onward', 'betube' ),
							)
						);
						?>
					</div>
				</div>
			</div><!--col-lg-8-->
			<?php if ( is_active_sidebar( 'pages' ) || is_active_sidebar( 'blog' )) { ?>
			<div class="col-lg-4 col-xl-3">
				<div class="btp_sidebar">
					<?php
					if ( is_post_type_archive( 'blog' ) || is_tax('blog_category')) {
						dynamic_sidebar('blog');
					}else{
						dynamic_sidebar('pages');
					}
					?>
				</div><!--btp_sidebar-->
			</div><!--col-lg-4-->
			<?php } ?>
		<?php else : ?>
			<div class="col-lg-12">
				<div class="row">
					<?php esc_html_e('No Content', 'betube'); ?>
				</div>
			</div>
		<?php endif; ?>
		</div><!--row-->
	</div><!--container-->
</section>
<?php get_footer(); ?>