<?php
/**
 * Template name: Register Page
 *
 * Learn more: http://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage betube
 * @since betube
 */

if ( is_user_logged_in() ) {
	$profile = betube_get_template_url('template-profile.php');
	wp_redirect( $profile ); exit;
}
global $registerSuccess, $betube_gdpr, $redux_demo, $reCAPTCHA;
$newUsernotification = $redux_demo['newusernotification'];
$registerSuccess = true;
if(isset($_POST['submit'])){
	$remember = esc_sql($_POST['remember']);
	if(!empty($remember)){			
		$message = esc_html__( 'Registration successful.', 'betube' );
		$username = esc_sql($_POST['username']);
		$email = esc_sql($_POST['email']);
		$password = esc_sql($_POST['password']);
		$confirm_password = esc_sql($_POST['confirm']);
		if(isset($_POST['gdpr'])){
			$betube_gdpr = true;
		}else{
			$betube_gdpr = false;
		}
		/*==========================
		First We will validate user data
		===========================*/
		if(empty($username)) {
			$message = esc_html__( 'User name should not be empty.', 'betube' );
			$registerSuccess = false;
		}
		if(isset($email)) {
			if (!preg_match("/^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,3})$/", $email)){
				$message = esc_html__( 'Please enter a valid email', 'betube' );
				$registerSuccess = false;
			}
		}else{
			$message = esc_html__( 'Please enter a valid email', 'betube' );
		}
		if(!empty($password)) {
			if (strlen($password) < 5 || strlen($password) > 15) {
				$message = esc_html__( 'Password must be 5 to 15 characters in length.', 'betube' );
				$registerSuccess = false;

			}elseif(isset($password) && $password != $confirm_password) {
				$message = esc_html__( 'Password Mismatch', 'betube' );
				$registerSuccess = false;
			}
		}
		/*==========================
		Google (reCAPTCHA) plugin
		Here we will check if plugin is 
		active and user have passed 
		captcha test
		===========================*/
		if ( function_exists( "gglcptch_display" ) && isset($_POST['g-recaptcha-response'])){
			if(empty($_POST['g-recaptcha-response'])){
				$reCAPTCHA = false;
				$registerSuccess = false;
				$message = esc_html__( 'Please complete reCAPTCHA.', 'betube' );
			}else{
				$reCAPTCHA = true;
			}
		}else{
			$reCAPTCHA = true;
		}
		if($reCAPTCHA == true && $registerSuccess == true){
			$userID = username_exists( $username );
			if ( ! $userID && false == email_exists( $email ) ) {
				$userID = wp_create_user( $username, $password, $email );
				if ( is_wp_error($userID) ) {
					$registerSuccess = false;
					$message =  esc_html__( 'Username or E-mail already exists. Please try another one.', 'betube' );
				}else{
					if($betube_gdpr == true){
						update_user_meta($userID, 'betube_gdpr', 'yes');
					}else{
						update_user_meta($userID, 'betube_gdpr', 'no');
					}
					beTubeUserNotification( $email, $password, $username );
					if($newUsernotification == 1){
						beTubeNewUserNotifiy($email, $username);	
					}
					$registerSuccess = true;
					$login_data = array();
					$login_data['user_login'] = $username;
					$login_data['user_password'] = $password;
					$user_verify = wp_signon( $login_data, false );
					$profile = betube_get_template_url('template-profile.php');
					wp_redirect( $profile ); exit;
				}
			}else{
				$registerSuccess = false;
				$message =  esc_html__( 'Username or E-mail already exists. Please try another one.', 'betube' );
			}
		}			
	}else{
		$message = esc_html__( 'You must need to agreed to terms and condition.', 'betube' );
		$registerSuccess = false;
	}
}
get_header(); ?>
<?php 
	$page = get_page($post->ID);
	$current_page_id = $page->ID;
	global $redux_demo;
	$login = betube_get_template_url('template-login.php');
	$betubeTerms = $redux_demo['termsandcondition'];
	$betubeLawURL = $redux_demo['lawdataurl'];
	$users_can_register = get_option('users_can_register');
	$betube_boxed= 'boxed';
	if(isset($redux_demo)){		
		$betube_boxed = $redux_demo['betube_boxed'];
	}
?>
<div class="container<?php if($betube_boxed == 'wide'){ echo "-fluid"; }?>">
	<div class="row">
		<div class="col-12">
			<!-- breadcrumb -->
			<nav aria-label="breadcrumb">
				<ol class="breadcrumb bg-transparent border-bottom mb-4 rounded-0 pl-0">
					<li class="breadcrumb-item">
						<a href="<?php echo esc_url(home_url()); ?>" class="breadcrumb-link">
							<?php esc_html_e('Home ', 'betube' ); ?>
						</a>
					</li>
					<li class="breadcrumb-item active" aria-current="page">
						<?php echo get_the_title(); ?>
					</li>
				</ol>
			</nav>
		</div><!--col-12-->
	</div><!--row-->
</div><!--container-->
<section class="btp_inner_page pb-5">
	<div class="container<?php if($betube_boxed == 'wide'){ echo "-fluid"; }?>">
		<div class="row">
			<?php if($users_can_register == true){?>
			<div class="col-lg-8 mx-auto">
				<h4 class="text-center mb-4"><?php the_title(); ?></h4>
				<div class="text-center mb-4">
				<?php
				if (have_posts()) : while (have_posts()) : the_post();
					the_content();
				endwhile; endif;
				?>
				</div>
				<?php if( class_exists( 'APSL_Lite_Class' ) ) { ?>
					<h5 class="mb-4 text-center"><?php esc_html_e('Login via Social Profile', 'betube'); ?></h5>
					<div class="accesspress mb-4">
					<?php echo do_shortcode('[apsl-login-lite]'); ?>
					</div>
					<h5 class="mb-4 text-center"><?php esc_html_e('or', 'betube'); ?></h5>
				<?php }elseif ( class_exists( 'APSP_Class' ) ) { ?>
					<h5 class="mb-4 text-center"><?php esc_html_e('Login via Social Profile', 'betube'); ?></h5>
					<div class="accesspress mb-4">
					<?php echo do_shortcode('[apsl-login]'); ?>
					</div>
					<h5 class="mb-4 text-center"><?php esc_html_e('or', 'betube'); ?></h5>
				<?php }elseif(class_exists('NextendSocialLogin', false)){ ?>
					<h5 class="mb-4 text-center"><?php esc_html_e('Login via Social Profile', 'betube'); ?></h5>
					<div class="accesspress mb-4">
					<?php echo NextendSocialLogin::renderButtonsWithContainer(); ?>
					</div>
					<h5 class="mb-4 text-center"><?php esc_html_e('or', 'betube'); ?></h5>
				<?php } ?>
				<h5 class="mb-4 text-center">
					<?php esc_html_e('Create your Account', 'betube'); ?>
				</h5>
			</div><!--col-lg-8-->
			<div class="col-lg-5 mx-auto">
				<?php				
				if($registerSuccess == false){
					echo '<p class="alert alert-danger">'.$message.'</p>';
				}
				?>
				<form class="validator" method="POST">
					<!--Username-->
					<div class="form-group">
						<div class="input-group">
							<div class="input-group-prepend">
								<span class="input-group-text bg-transparent border-right-0">
									<i class="fas fa-user-circle input-group-text-icon"></i>
								</span>
							</div>
							<input id="signupUsername" type="text" name="username" class="form-control border-left-0" placeholder="<?php esc_attr_e('Enter your username', 'betube'); ?>" aria-label="Username" data-rule-required="true" data-msg="<?php esc_attr_e('Username is required', 'betube'); ?>" required>
							<div class="valid-feedback">
								<?php esc_html_e('Looks good!', 'betube'); ?>
							</div>
							<div class="invalid-feedback">
							</div>
						</div><!--input-group-->
					</div>
					<!--Username-->
					<!--Email-->
					<div class="form-group">
						<div class="input-group">
							<div class="input-group-prepend">
								<span class="input-group-text bg-transparent border-right-0">
									<i class="fas fa-envelope input-group-text-icon"></i>
								</span>
							</div>
							<input id="signupEmail" type="email" name="email" class="form-control border-left-0" placeholder="<?php esc_attr_e('Enter your email', 'betube'); ?>" aria-label="email" data-rule-required="true" data-msg="<?php esc_attr_e('Please provide valid Email', 'betube'); ?>" required>
							<div class="valid-feedback">
								<?php esc_html_e('Looks good!', 'betube'); ?>
							</div>
							<div class="invalid-feedback"> </div>
						</div>
					</div>
					<!--Email-->
					<!--Password-->
					<div class="form-group">
						<div class="input-group">
							<div class="input-group-prepend">
								<span class="input-group-text bg-transparent border-right-0">
									<i class="fas fa-key input-group-text-icon"></i>
								</span>
							</div>
							<input id="password" name="password" type="password" class="form-control border-left-0" placeholder="<?php esc_attr_e('Enter your Password', 'betube'); ?>" aria-label="password" data-rule-required="true" data-msg="<?php esc_attr_e('Password is required', 'betube'); ?>" autocomplete="new-password" required>
							<div class="valid-feedback">
								<?php esc_html_e('Looks good!', 'betube'); ?>
							</div>
							<div class="invalid-feedback">
								<?php esc_html_e('Please enter password.', 'betube'); ?>
							</div>
						</div>
					</div>
					<!--Password-->
					<!--Re-Enter Password-->
					<div class="form-group">
						<div class="input-group">
							<div class="input-group-prepend">
								<span class="input-group-text bg-transparent border-right-0">
									<i class="fas fa-key text-danger input-group-text-icon"></i>
								</span>
							</div>
							<input id="signupRePass" name="confirm" type="password" class="form-control border-left-0" placeholder="<?php esc_attr_e('Confirm password', 'betube'); ?>" aria-label="confirmpassword" data-rule-equalTo="#password" data-rule-required="true" data-msg="<?php esc_attr_e('Password not matched', 'betube'); ?>">
							<div class="valid-feedback">
								<?php esc_html_e('Looks good!', 'betube'); ?>
							</div>
							<div class="invalid-feedback">
							   <?php esc_html_e('Password mismatch.', 'betube'); ?>
							</div>
						</div>
					</div>
					<!--Re-Enter Password-->
					<!--Terms-->
					<div class="form-group">
						<div class="custom-control custom-checkbox">
							<input type="checkbox" class="custom-control-input" id="termsCondition" name="remember" data-rule-required="true" data-msg="<?php esc_attr_e('You must agree before submitting', 'betube'); ?>" value="forever" required>
							<label class="custom-control-label" for="termsCondition">
							<?php esc_html_e("Agreed to", 'betube'); ?>
							<a target="_blank" href="<?php echo esc_url($betubeTerms); ?>">
								<?php esc_html_e('terms & Condition.', 'betube'); ?>
							</a>
							</label>
							<div class="valid-feedback">
								<?php esc_html_e('Looks good!', 'betube'); ?>
							</div>
							<div class="invalid-feedback">
								<?php esc_html_e('You must agree before submitting.', 'betube'); ?>
							</div>
						</div>
					</div>
					<!--Terms-->
					<!--GDPR-->
					<div class="form-group">
						<div class="custom-control custom-checkbox">
							<input type="checkbox" class="custom-control-input" name="gdpr" id="gdpr" value="gdpr" required>
							<label class="custom-control-label" for="gdpr">
								<?php esc_html_e("Agreed to", 'betube'); ?>
								<a target="_blank" href="<?php echo esc_url($betubeLawURL); ?>">
									<?php esc_html_e('GDPR', 'betube'); ?>
								</a>
								<?php esc_html_e(', keep me informed via email about my account info and posts related emails.', 'betube'); ?>
							</label>
							<div class="valid-feedback">
								<?php esc_html_e('Looks good!', 'betube'); ?>
							</div>
							<div class="invalid-feedback">
								<?php esc_html_e('You must agree before submitting.', 'betube'); ?>
							</div>
						</div>
					</div>
					<!--GDPR-->
					<!--Google-->
					<?php if ( function_exists( 'gglcptch_display' ) ) { ?>
						<div class="form-group">
						<?php 
						echo apply_filters( 'gglcptch_display_recaptcha', '', 'betube_register_form');
						?>										
						</div>
					<?php } ?>									
					<!--Google-->
					<button type="submit" name="submit" class="btn btn-danger btn-block mb-4"><?php esc_html_e('Sign Up', 'betube'); ?></button>
                    <p><?php esc_html_e('Already have account?', 'betube'); ?>&nbsp;<a href="<?php echo esc_url($login); ?>" class="text-danger"><?php esc_html_e('Login here', 'betube'); ?></a></p>
				</form>
			</div><!--col-lg-5-->
			<?php }else{ ?>
			<div class="col-lg-12 mx-auto">
				<h5 class="alert alert-info"><?php esc_html_e('Registration is currently disabled. Please try again later.', 'betube') ?></h5>
			</div>
			<?php } ?>
		</div><!--row-->
	</div><!--container-->
</section>
<?php get_footer(); ?>