<?php
if( ! function_exists('btp_page_layout')){
	add_action( 'add_meta_boxes', 'btp_page_layout' );
	function btp_page_layout() {
		add_meta_box( 
			'btp_layout',
			esc_html__( 'Homepage layout', 'betubepro' ),
			'btp_page_layout_content',
			'page',
			'side',
			'high'
		);
	}
	function btp_page_layout_content() {
		global $post;
		wp_nonce_field( 'btp_layout_check_box', 'btp_layout_check_box_nonce' );
		$btp_layout = get_post_meta($post->ID, 'btp_layout', true);
		?>
		<label>
			<input type="radio" name="btp_layout" value="fullwidth" <?php if($btp_layout == 'fullwidth'){echo "checked";}?>>
			<?php esc_html_e( 'Full width', 'betube' ); ?>
		</label><br/>
		<label>
			<input type="radio" name="btp_layout" value="sidebar" <?php if($btp_layout == 'sidebar'){echo "checked";}?>>
			<?php esc_html_e( 'With sidebar', 'betube' ); ?>
		</label><br/>
		<p><?php esc_html_e( 'This option will work only with homepage, For other pages you can select from theme options.', 'betube' ); ?></p>
		<?php
	}
	add_action( 'save_post', 'btp_page_layout_save' );
	function btp_page_layout_save($post_id){
		if ( ! isset( $_POST['btp_layout_check_box_nonce'] ) ){
			return;
		}
		if ( ! wp_verify_nonce( $_POST['btp_layout_check_box_nonce'], 'btp_layout_check_box' ) ) {
			return;
		}
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}
		if ( !current_user_can( 'edit_post', $post_id )){
			return $post_id;
		}
		if( isset( $_POST['btp_layout'] ) ){
			update_post_meta( $post_id, 'btp_layout', esc_attr( $_POST['btp_layout'] ) );
		}
	}
}
if( ! function_exists('cd_meta_box_save')){
	add_action( 'add_meta_boxes', 'betube_meta_box_add' );
	function betube_meta_box_add(){	
		add_meta_box( 'page_metabox', esc_html__( 'Page meta', 'betube' ), 'betube_page_metabox', 'page', 'side', 'high' );
	}
	function betube_page_metabox( $post ){
		$values = get_post_custom( $post->ID );
		$layerslider_shortcode = isset( $values['layerslider_shortcode'] ) ? esc_attr( $values['layerslider_shortcode'][0] ) : '';
		$page_custom_title = isset( $values['page_custom_title'] ) ? esc_attr( $values['page_custom_title'][0] ) : '';

		$selected = isset( $values['page_slider'] ) ? esc_attr( $values['page_slider'][0] ) : '';
		wp_nonce_field( 'my_meta_box_nonce', 'meta_box_nonce' );
		?>
		
		<div class="btpro_page_meta form-wrap">
			<div class="components-base-control">
				<div class="components-base-control__field">
					<label class="components-base-control__label">
						<?php esc_html_e( 'Page slider : Only for homepage', 'betube' ); ?>
					</label>
					<select name="page_slider" id="page_slider" class="components-select-control__input" style="width: 80%;">
						<option value="none" <?php selected( $selected, 'none' ); ?>>
							<?php esc_html_e( 'none', 'betube' ); ?>
						</option>
						<option value="LayerSlider" <?php selected( $selected, 'LayerSlider' ); ?>>
							<?php esc_html_e( 'LayerSlider', 'betube' ); ?>
						</option>
					</select>
				</div><!--components-base-control__field-->
				<div class="components-base-control__field" id="layerslidershortcode" style="display: none;">
					<label class="components-base-control__label">
						<?php esc_html_e( 'LayeSlider Shortcode', 'betube' ); ?>
					</label>
					<input type="text" name="layerslider_shortcode" id="layerslider_shortcode" value="<?php echo $layerslider_shortcode; ?>" / class="components-text-control__input">
					<p><?php esc_html_e( 'Enter layerslider shortcode (leave empty for)', 'betube' ); ?> [layerslider id="1"].</p>
				</div><!--components-base-control__field-->
			</div><!--components-base-control-->
			<script>
			jQuery(document).ready(function(){
				var page_slider = jQuery("#page_slider").val();
				if( page_slider === "LayerSlider" ) {
					jQuery("#layerslidershortcode").css({"display":"block"});
				} else {
					jQuery("#layerslidershortcode").css({"display":"none"});
				}				
				jQuery("#page_slider").change(function() {
					var page_slider = jQuery(this).val();
					if( page_slider === "LayerSlider" ) {
						jQuery("#layerslidershortcode").css({"display":"block"});
					} else {
						jQuery("#layerslidershortcode").css({"display":"none"});
					}
				});
			});
			</script>
		</div>		
		<?php	
	}
}
if( ! function_exists('cd_meta_box_save')){
	add_action( 'save_post', 'cd_meta_box_save' );
	function cd_meta_box_save( $post_id ){		
		if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return;
		if( !isset( $_POST['meta_box_nonce'] ) || !wp_verify_nonce( $_POST['meta_box_nonce'], 'my_meta_box_nonce' ) ){ return;}
		if ( !current_user_can( 'edit_post', $post_id )){ return; }
		$allowed = array( 
			'a' => array(
				'href' => array()
			)
		);		
		if( isset( $_POST['layerslider_shortcode'] ) ){
			update_post_meta( $post_id, 'layerslider_shortcode', wp_kses( $_POST['layerslider_shortcode'], $allowed ) );
		}
		if( isset( $_POST['page_slider'] ) ){
			update_post_meta( $post_id, 'page_slider', esc_attr( $_POST['page_slider'] ) );
		}
	}
}
?>