<?php 
class btp_recent_blogposts_widget extends WP_Widget{
	/*==========================
	Sets up the widgets name
	===========================*/
	public function __construct() {
		$widget_ops = array( 
			'classname' => 'widget_latest_blog_post',
			'description' => esc_html__( 'BeTube recent blog posts', 'betubepro-helper' ),
		);
		parent::__construct( 'btp_recent_blog_widget', esc_html__( 'BeTube recent blog posts', 'betubepro-helper' ), $widget_ops );
	}
	/*==========================
	Outputs the content of the widget
	@param array $args
	@param array $instance
	===========================*/
	public function widget( $args, $instance ) {
		echo $args['before_widget'];
		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}
		$btpargs = array(
			'post_type' => 'blog',
			'post_status' => 'publish',
			'posts_per_page' => $instance['number_posts'],
		);
		$btpWidgetPosts = get_posts($btpargs);		
		$btp_style = $instance['btp_style'];
		$beTubedateFormat = get_option( 'date_format' );		
		if($btp_style == 'v1'){
		?>
		<div class="widget_content widget_latest_post_content">
			<?php
			if ( $btpWidgetPosts ) {
				foreach ( $btpWidgetPosts as $post ){
					setup_postdata( $post );
					?>
					<div class="widget_latest_post__box mb-4">
						<h6 class="widget_latest_post__title text-truncate">
							<a href="<?php the_permalink($post->ID); ?>">
								<?php echo get_the_title($post->ID);?>
							</a>
                        </h6>
						<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>" class="d-inline-flex align-items-center widget_latest_post__link mr-3">
							<i class="fas fa-user-circle mr-2"></i>
							<?php the_author(); ?>
						</a>
						<a href="<?php echo get_day_link(get_the_time('Y'), get_the_time('m' ), get_the_time('d'));?>" class="d-inline-flex align-items-center widget_latest_post__link mr-3">
							<i class="fas fa-calendar-alt mr-2"></i>
							<?php echo get_the_date($beTubedateFormat, $post->ID); ?>
						</a>
					</div>
					<?php
				}wp_reset_postdata();
			}
			?>
		</div>
		<?php }elseif($btp_style == 'v2'){ ?>
		<div class="widget_content">
			<?php
			if ( $btpWidgetPosts ) {
				foreach ( $btpWidgetPosts as $post ){
					setup_postdata( $post );
					$thumbURL = get_the_post_thumbnail_url($post->ID);					
					?>
			<figure class="widget_latest_videos d-flex align-items-center">
				<?php if( has_post_thumbnail($post->ID)){ ?>
				<a href="<?php the_permalink($post->ID); ?>" class="card border-0 d-block mb-0 widget_latest_videos__box">
					<img class="widget_latest_videos__img" src="<?php echo esc_url($thumbURL);?>" alt="<?php echo get_the_title($post->ID);?>">
				</a>
				<?php } ?>
				<figcaption>
					<h6 class="mb-0 widget_most_view__title block_with_heading">
						<a href="<?php the_permalink($post->ID); ?>" class="widget_most_view__title_link text-decoration-none">
							<?php echo get_the_title($post->ID);?>
						</a>
					</h6>
					<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>" class="mb-1 small widget_most_view__link text-decoration-none">
						<?php the_author(); ?>
						<i class="ml-1 fas fa-check-circle"></i>
					</a>
					<p class="mb-0">
						<span class="small"><?php echo betubepro_posted_ago($post->ID); ?></span>
					</p>
				</figcaption>
			</figure>
				<?php
				}wp_reset_postdata();
			}
			?>
		</div>
		<?php }else{ ?>
		<div class="widget_content">
			<?php
			if ( $btpWidgetPosts ) {
				foreach ( $btpWidgetPosts as $post ){
					setup_postdata( $post );
					$thumbURL = get_the_post_thumbnail_url($post->ID);					
					?>
				<figure class="widget_most_view">
					<?php if( has_post_thumbnail($post->ID)){ ?>
					<a href="<?php the_permalink($post->ID); ?>" class="card border-0 d-block mb-2">
						<img src="<?php echo esc_url($thumbURL);?>" alt="<?php echo get_the_title($post->ID);?>">
					</a>
					<?php } ?>
					<figcaption>
						<h6 class="mb-0 widget_most_view__title text-truncate">
							<a href="<?php the_permalink($post->ID); ?>" class="widget_most_view__title_link text-decoration-none">
							<?php echo get_the_title($post->ID);?>
							</a>
						</h6>
						<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>" class="mb-1 small widget_most_view__link text-decoration-none">
							<?php the_author(); ?>
							<i class="ml-1 fas fa-check-circle"></i>
						</a>
						<p class="mb-0">							
							<span class="small"><?php echo betubepro_posted_ago($post->ID); ?></span>
						</p>
					</figcaption>
				</figure>
				<?php
				}wp_reset_postdata();
			}
			?>
		</div>
		<?php }
		echo $args['after_widget'];
	}
	/*==========================
	Outputs the options form on admin
	@param array $instance The widget options
	===========================*/
	public function form( $instance ) {
		$title = ! empty( $instance['title'] ) ? $instance['title'] : esc_html__( 'BeTube Recent Blog Posts', 'betubepro-helper' );
		$btp_style = ! empty( $instance['btp_style'] ) ? $instance['btp_style'] : 'v1';
		$number_posts = ! empty( $instance['number_posts'] ) ? $instance['number_posts'] : 3;
		?>
		<!--Title Field-->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>">
				<?php esc_attr_e( 'Title:', 'betubepro-helper' ); ?>
			</label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>
		<!--Style Field-->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'btp_style' ) ); ?>">
				<?php esc_attr_e( 'Posts styles', 'betubepro-helper' ); ?>
			</label>
			<select class="widefat" id="<?php echo esc_attr($this->get_field_id('btp_style')); ?>" name="<?php echo esc_attr($this->get_field_name('btp_style')); ?>">
                <option value="v1" <?php if ($btp_style == 'v1') print 'selected="selected"'; ?>>
					<?php esc_html_e('Without thumbnail', 'betubepro-helper');?>
				</option>
                <option value="v2" <?php if ($btp_style == 'v2') print 'selected="selected"'; ?>>
					<?php esc_html_e('Small thumbnail', 'betubepro-helper');?>
				</option>
				<option value="v3" <?php if ($btp_style == 'v3') print 'selected="selected"'; ?>>
					<?php esc_html_e('Large Thumbnail', 'betubepro-helper');?>
				</option>
            </select>
		</p>
		<!--Post Count-->
		<p>
            <label for="<?php echo esc_attr($this->get_field_id('number_posts')); ?>">
				<?php esc_html_e('Number of posts to show', 'betubepro-helper');?>:
			</label>
            <input  id="<?php echo esc_attr($this->get_field_id('number_posts')); ?>" name="<?php echo esc_attr($this->get_field_name('number_posts')); ?>" value="<?php echo esc_attr($number_posts); ?>" size="3"  />
        </p>
		<?php
	}
	/*==========================
	Processing widget options on save
	@param array $new_instance The new options
	@param array $old_instance The previous options
	@return array
	===========================*/
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
		$instance['btp_style'] = ( ! empty( $new_instance['btp_style'] ) ) ? sanitize_text_field( $new_instance['btp_style'] ) : '';
		$instance['number_posts'] = ( ! empty( $new_instance['number_posts'] ) ) ? sanitize_text_field( $new_instance['number_posts'] ) : '';
		return $instance;
	}
}
/*==========================
Register Recent post widget
using widgets_init hook
===========================*/
add_action( 'widgets_init', function(){
	register_widget( 'btp_recent_blogposts_widget' );
});